* NOTE: You need to set the Stata working directory to the path where the data file is located using local variable `current'.
clear
local current `"current"'
cd `current'
capture mkdir dta_files_stock
capture mkdir adjustment_usual_PT_until89
local folder_UPT `"adjustment_usual_PT_until89"'
set more off

local method_deNUN=0
local IPT_VPT=1			/* dustingish PT into involuntary and voluntary one */
local end_sample = 201901


local first1=197601
local end   =`end_sample'-1
local first = `first1'
local count = 0

while `first' <= `end' +1   {
	local count = `count' + 1
	use IPUMS_CPS_data`first'.dta, clear
	disp `first'
	
	drop if inlist(empstat,  00, 01) | classwkr == 26   /*drop people who answered NIU and are on active duty in the U.S. Armed Forces. */
	drop if age < 16 | age ==.
	drop if classwkr == 29		/* exclude unpaid family workers */
	drop if classwkr == 13		/* exclude unincorpated self-employed */
	
	quietly{ 
		gen self = .
		replace self = 0 if labforce == 2
		replace self = 1 if labforce == 2 &  inlist(classwkr, 10, 13, 14)
		
		gen agri = .
		replace agri = 0 if labforce == 2
		replace agri = 1 if labforce == 2 &  inlist(ind, 10, 11, 12, 20, 30, 31, 32 )
		
		gen lst =.
		replace lst = 1 if inlist(empstat,  30, 31, 32, 33, 34, 35, 36)   	/* Not In Labor Force */
		replace lst = 4 if inlist(empstat,  20, 21, 22) & fpstate == 50		/* UF */
		replace lst = 5 if inlist(empstat,  20, 21, 22) & fpstate == 60		/* UP */
		
		gen part_iv = .				/* For only PT. Whether they are voluntary or involuntary: part_iv=1 if they are involuntary and =2 if voluntary*/
		gen report_usual_hours = .
		gen drop_emp = .

		
		if `first' <= 198112 {
			replace lst = 2 if inlist(empstat,  10, 12) & fpstate == 10  					/* NF */
			replace lst = 3 if inlist(empstat,  10, 12) & (fpstate == 20  | fpstate == 40)	/* NP */
			replace part_iv = 1 if (lst == 3) & (fpstate == 20)	  							/* 20: Part-time for economic reasons */
			replace part_iv = 2 if (lst == 3) & (fpstate == 40)	  							/* 40: Part-time for non-economic reasons, usually part-time */
		}
		else if (`first' >= 198201 & `first' <= 199312 ){
			replace ahrswork1 = -1 if ahrswork1 == .
			replace lst = 2 if inlist(empstat,  10, 12) & ((uhrswork1>=35 & uhrswork1<997) | (uhrswork1==0 & (ahrswork1 >=35 & ahrswork1<=120)) |  (uhrswork1==997 & inlist(fpstate, 10, 21)))	/* NF */
			replace lst = 3 if inlist(empstat,  10, 12) & ((uhrswork1<35  & 0<uhrswork1)   | (uhrswork1==0 & (0< ahrswork1 & ahrswork1 <35)) | (uhrswork1==997 & inlist(fpstate, 20, 22, 40)))	/* NP */
			replace lst = 2 if lst == . & inlist(empstat,  10, 12) & inlist(fpstate, 10, 21)		/* NF */
			replace lst = 3 if lst == . & inlist(empstat,  10, 12) & inlist(fpstate, 20, 22, 40)	/* NP */
			replace part_iv = 1 if (lst == 3) & inlist(fpstate, 20, 22)	  						    /* 22: Part-time for economic reasons */
			replace part_iv = 2 if (lst == 3) & fpstate == 40	  									/* 40: Part-time for non-economic reasons, usually part-time */
		}
		else if (`first' >= 199401 ){
			replace ahrsworkt = -1 if ahrsworkt== .
			replace lst = 2 if inlist(empstat,  10, 12) & ((uhrsworkt>=35 & uhrsworkt<997) | (uhrsworkt==0 & (ahrsworkt >=35 & ahrsworkt<=120)) |  (uhrsworkt==997 & (ahrsworkt >=35 & ahrsworkt<=120)))	/* NF */
			replace lst = 3 if inlist(empstat,  10, 12) & ((uhrsworkt<35  & 0<uhrsworkt)   | (uhrsworkt==0 & (0< ahrsworkt & ahrsworkt <35)) | (uhrsworkt==997 & (0< ahrsworkt & ahrsworkt <35)))	/* NP */
			replace lst = 2 if lst == . & inlist(empstat,  10, 12) & inlist(fpstate, 11, 12, 13, 21)	/* NF */
			replace lst = 3 if lst == . & inlist(empstat,  10, 12) & inlist(fpstate, 14, 15, 22, 41, 42)	/* NP */
			replace part_iv = 1 if (lst == 3) & inlist(fpstate, 14, 22)	  							/* 14: Full-time hours, usually part-time for economic reasons, 22 Part-time hours, usually part-time for economic reasons */
			replace part_iv = 2 if (lst == 3) & inlist(fpstate, 15, 41, 42)	 	  					/* 15: Full-time hours, usually part-time for non-economic reasons, 41: Part-time hours, usually part-time for non-economic reasons, 42: Not at work, usually part-time */
		}
		if `first' >= 199401 {
			gen samejob =.
			replace samejob = 1 if empsame == 02
			replace samejob = 2 if empsame == 01
			replace samejob = -1 if inlist(empsame,  96, 97, 99)
			
			replace numjob=. if numjob == 0
			replace numjob=1 if inlist(lst, 2, 3) & multjob == 1 & numjob==.
		}
		
		replace report_usual_hours = 0 if inlist(lst,  2, 3)
		replace report_usual_hours = 1 if (inlist(lst,  2, 3) & (uhrsworkt>0 & uhrsworkt<997))
		replace drop_emp = 1 if inlist(empstat,  10, 12)
		replace drop_emp = 0 if (inlist(empstat,  10, 12) & inlist(lst, 2,3))

		if `method_deNUN' == 1 {
			forval i =1/4 {
				gen lst`i'_new =.
			}
		}
		* Classifying EP into EIP and EVP
		gen lst_detail =lst
		replace lst_detail = 31 if  (lst == 3) & (part_iv == 1) 		/* involuntary PT */
		replace lst_detail = 32 if  (lst == 3) & (part_iv == 2)			/* voluntary PT */
	}
	quietly save `current'\dta_files_stock\IPUMS_CPS_data_lst`first'.dta, replace
	
	preserve
	quietly{
		drop if drop_emp == .
		sort drop_emp
		egen double fw_drop_emp = total(fweight), by(drop_emp)	
		egen double total_fw_drop_emp = total(fweight)
		quietly by drop_emp:  gen duplic = cond(_N==1,0,_n)
		drop if duplic > 1
		gen  prob_fw_drop_emp = fw_drop_emp/total_fw_drop_emp
		keep drop_emp prob_fw_drop_emp	
		gen date = `first' 
		
		gen str4 year=substr(string(date),1,4)
		gen str2 month=substr(string(date),5,6)
		gen year_n = real(year)
		gen month_n = real(month)
		gen survey = ym(year_n, month_n)
		order survey, after(date) 
		drop year month year_n month_n
		reshape wide prob_fw_drop_emp, i(date) j(drop_emp)
		if `count' >=2 { 
			append using rate_drop_emp.dta
			sort date
			}	
		save rate_drop_emp.dta, replace
	}
	restore
	
	if (`first' >= 198901 & `first' <= 199312 ) {
		preserve
		quietly{
			gen date = `first' 		
			keep if inlist(fpstate, 20, 21, 22, 40, 41, 42)
			gen PTE_all = 0		
			replace PTE_all = 1 if inlist(fpstate, 21, 22)
			gen PTE_UFT = 0 			
			replace PTE_UFT = 1 if inlist(fpstate, 21)
			gen fw_PTE = 0
			gen fw_PTE_UFT = 0
			replace fw_PTE = fweight if PTE_all == 1
			replace fw_PTE_UFT = fweight if (PTE_all == 1 & PTE_UFT == 1)
			egen double sum_fw_PT = total(fweight)
			egen double sum_fw_PTE = total(fw_PTE)
			egen double sum_fw_PTE_UFT = total(fw_PTE_UFT)
			gen share_PTE = sum_fw_PTE/sum_fw_PT
			gen share_UFT = sum_fw_PTE_UFT/sum_fw_PT
			gen share_UFT_PTE = share_UFT/share_PTE
			keep date year month share_PTE  share_UFT share_UFT_PTE
			keep if _n==1
			if (`first' >= 198902) {
				append using `folder_UPT'\PT_UFT.dta
				sort date
			}
			save `folder_UPT'\PT_UFT.dta, replace		
		}
		restore
	}
	* compute the probality of the employed workers who report usual hours worked
	quietly{
		drop if report_usual_hours == .
		sort report_usual_hours
		egen double fw_report = total(fweight), by(report_usual_hours)	
		egen double total_fw_report = total(fweight)
		quietly by report_usual_hours:  gen duplic = cond(_N==1,0,_n)
		drop if duplic > 1
		gen  prob_fw_report = fw_report/total_fw_report
		keep report_usual_hours prob_fw_report		
		gen date = `first' 
		
		gen str4 year=substr(string(date),1,4)
		gen str2 month=substr(string(date),5,6)
		gen year_n = real(year)
		gen month_n = real(month)
		gen survey = ym(year_n, month_n)
		order survey, after(date) 
		drop year month year_n month_n
		reshape wide prob_fw_report, i(date) j(report_usual_hours)
		if `count' >=2 { 
			append using report_usual_hours.dta
			sort date
			}	
		save report_usual_hours.dta, replace		
	}
	
	local second = `first' + 1
	if (`first'-12)/100 == int((`first'-12)/100) {
		local second = `first' + 89
	}
	local first=`second'
}


if `method_deNUN' == 1 {
	noisily disp `method_deNUN'
	local first1=197801
	local end   =`end_sample'
	local first = `first1'
	local memo_data `"`first1'"'
	while `first' <= `end' -3   {
		disp `first'
		local second = `first' + 1
		if (`first'-12)/100 == int((`first'-12)/100) {
			local second = `first' + 89
		}
		local third = `second' + 1
		if (`second'-12)/100 == int((`second'-12)/100) {
			local third = `second' + 89
		}
		local fourth = `third' + 1
		if (`third'-12)/100 == int((`third'-12)/100) {
			local fourth = `third' + 89
		}

		
		if (`first' != 198507 & `second' != 198507 & `third' != 198507 & `fourth' != 198507 & /*
		*/ `first' != 198510 & `second' != 198510 & `third' != 198510 & `fourth' != 198510	& /*
		*/ `first' != 199506 & `second' != 199506 & `third' != 199506 & `fourth' != 199506  & /*
		*/ `first' != 199507 & `second' != 199507 & `third' != 199507 & `fourth' != 199507  & /*
		*/ `first' != 199508 & `second' != 199508 & `third' != 199508 & `fourth' != 199508  & /*
		*/ `first' != 199509 & `second' != 199509 & `third' != 199509 & `fourth' != 199509) {
			local f = `"`first'"'
			if `first' != `first1' {
				local memo_data = `"`memo_data'"' + `"`first'"'
			}
			use dta_files_stock\IPUMS_CPS_data_lst`first'.dta, clear
			quietly {
				drop self agri uhrsworkt uhrswork* ahrswork* empstat whyptlwk empsame multjob numjob classwkr ind
				rename lst lst11
				rename mis mis11
				rename tm tm11
				rename mdate mdate11
				rename year year11
				rename month month11
				rename serial serial11
				rename fweight fweight11
				*rename pernum pernum11
			}
			sort cpsidp race sex mis11
			quietly by cpsidp race sex mis11: gen dup = cond(_N==1,0,_n)
				*** Flag any duplicate records so none of them can be matched.
			sort cpsidp race sex mis11 dup
			quietly save `first'm1, replace
			
			
			use dta_files_stock\IPUMS_CPS_data_lst`second'.dta, clear
			quietly {
				drop self agri uhrsworkt uhrswork* ahrswork* empstat whyptlwk empsame multjob numjob classwkr ind
				keep if mis == 2 | mis == 6
				rename lst lst12
				rename mis mis12
				rename tm tm12
				rename mdate mdate12
				rename fweight fweight12
				gen mis11 = mis12 - 1
			}
			sort cpsidp race sex mis11
			quietly by cpsidp race sex mis11: gen dup = cond(_N==1,0,_n)
				*** Flag any duplicate records so none of them can be matched.
			sort cpsidp race sex mis11 dup
			quietly save `second'm2, replace		
			merge cpsidp race sex mis11 dup using `first'm1
			rename _merge _merge1
			quietly keep if _merge1 == 3
			quietly drop dup
			sort cpsidp race sex mis11
			quietly by cpsidp race sex mis11: gen dup = cond(_N==1,0,_n)
				*** Flag any duplicate records so none of them can be matched.
			sort cpsidp race sex mis11 dup
			quietly save `first'and`second'm1.dta, replace
			erase `first'm1.dta
			erase `second'm2.dta
			
			use dta_files_stock\IPUMS_CPS_data_lst`third'.dta, clear
			quietly {
				drop self agri uhrsworkt uhrswork* ahrswork* empstat whyptlwk empsame multjob numjob classwkr ind
				keep if mis == 3 | mis == 7
				rename lst lst13
				rename mis mis13
				rename tm tm13
				rename mdate mdate13
				rename fweight fweight13
				gen mis11 = mis13 - 2
			}
			sort cpsidp race sex mis11
			quietly by cpsidp race sex mis11: gen dup = cond(_N==1,0,_n)
				*** Flag any duplicate records so none of them can be matched.
			sort cpsidp race sex mis11 dup
			quietly save `third'm3, replace
			merge cpsidp race sex mis11 dup using `first'and`second'm1
			rename _merge _merge2
			quietly keep if _merge2 == 3
			quietly drop dup
			sort cpsidp race sex mis11
			quietly by cpsidp race sex mis11: gen dup = cond(_N==1,0,_n)
				*** Flag any duplicate records so none of them can be matched.
			sort cpsidp race sex mis11 dup
			quietly save `first'and`third'm1.dta, replace
			erase `third'm3.dta
			erase `first'and`second'm1.dta
			
			use dta_files_stock\IPUMS_CPS_data_lst`fourth'.dta, clear
			quietly {
				drop self agri uhrsworkt uhrswork* ahrswork* empstat whyptlwk empsame multjob numjob classwkr ind
				keep if mis == 4 | mis == 8
				rename lst lst14
				rename mis mis14
				rename tm tm14
				rename mdate mdate14
				rename fweight fweight14
				gen mis11 = mis14 - 3
			}
			sort cpsidp race sex mis11
			quietly by cpsidp race sex mis11: gen dup = cond(_N==1,0,_n)
				*** Flag any duplicate records so none of them can be matched.
			sort cpsidp race sex mis11 dup
			quietly save `fourth'm4, replace
			*use `fourth'm4, clear
			merge cpsidp race sex mis11 dup using `first'and`third'm1
			rename _merge _merge3
			quietly keep if _merge3 == 3
			quietly drop dup
			sort cpsidp race sex mis11
			quietly by cpsidp race sex mis11: gen dup = cond(_N==1,0,_n)
				*** Flag any duplicate records so none of them can be matched.
			sort cpsidp race sex mis11 dup
			quietly{
				order year11, first
				order month11, after(year11)
				order tm11, after(month11)
				order tm14, after(tm11)
				order mdate11, after(tm14)
				order mdate12, after(mdate11)
				order mdate13, after(mdate12)
				order mdate14, after(mdate13)
				order year, after(mdate14)
				order month, after(year)
				order mis11, after(race)
				order mis12, after(mis11)
				order mis13, after(mis12)
				order mis14, after(mis13)
				order lst11, after(mis14)
				order lst12, after(lst11)
				order lst13, after(lst12)
				order lst14, after(lst13)
				order fweight12, after(fweight11)
				order fweight13, after(fweight12)
				order fweight14, after(fweight13)
				drop tm12 tm13 year month
				tostring lst11 lst12 lst13 lst14, gen(lst11s lst12s lst13s lst14s)
				gen lst_trans = lst11s+lst12s+lst13s+lst14s
				*destring lst_trans, replace
				drop lst11s lst12s lst13s lst14s
				gen N11 = (lst_trans=="1141"|lst_trans=="1411"|lst_trans=="1151"|lst_trans=="1511")
				gen N02 = (lst_trans=="2141"|lst_trans=="2151")
				gen N03 = (lst_trans=="3141"|lst_trans=="3151")
				gen N12 = (lst_trans=="1412"|lst_trans=="1512")
				gen N13 = (lst_trans=="1413"|lst_trans=="1513")
				gen UF11 =(lst_trans=="4454"|lst_trans=="4544"|lst_trans=="4414"|lst_trans=="4414")
				gen UF02 =(lst_trans=="2414"|lst_trans=="2454")
				gen UF03 =(lst_trans=="3414"|lst_trans=="3454")
				gen UF12 =(lst_trans=="4142"|lst_trans=="4542")
				gen UF13 =(lst_trans=="4143"|lst_trans=="4543")
				gen UP11 =(lst_trans=="5545"|lst_trans=="5455"|lst_trans=="5515"|lst_trans=="5155")
				gen UP02 =(lst_trans=="2515"|lst_trans=="2545")
				gen UP03 =(lst_trans=="3515"|lst_trans=="3545")	
				gen UP12 =(lst_trans=="5152"|lst_trans=="5452")
				gen UP13 =(lst_trans=="5153"|lst_trans=="5453")	
				gen lst_trans_new = lst_trans
				replace lst_trans_new = "1111" if N11 == 1
				replace lst_trans_new = "2111" if N02 == 1
				replace lst_trans_new = "3111" if N03 == 1
				replace lst_trans_new = "1112" if N12 == 1
				replace lst_trans_new = "1113" if N13 == 1
				replace lst_trans_new = "4444" if UF11 == 1
				replace lst_trans_new = "2444" if UF02 == 1
				replace lst_trans_new = "3444" if UF03 == 1
				replace lst_trans_new = "4442" if UF12 == 1
				replace lst_trans_new = "4443" if UF13 == 1
				replace lst_trans_new = "5555" if UP11 == 1
				replace lst_trans_new = "2555" if UP02 == 1
				replace lst_trans_new = "3555" if UP03 == 1
				replace lst_trans_new = "5552" if UP12 == 1
				replace lst_trans_new = "5553" if UP13 == 1
				order lst_trans_new, after(lst_trans)
				gen check_deNUN = 0
				replace check_deNUN = 1 if N11 == 1
				replace check_deNUN = 2 if N02 == 1
				replace check_deNUN = 3 if N03 == 1
				replace check_deNUN = 4 if N12 == 1
				replace check_deNUN = 5 if N13 == 1
				replace check_deNUN = 6 if UF11 == 1
				replace check_deNUN = 7 if UF02 == 1
				replace check_deNUN = 8 if UF03 == 1
				replace check_deNUN = 9 if UF12 == 1
				replace check_deNUN = 10 if UF13 == 1
				replace check_deNUN = 11 if UP11 == 1
				replace check_deNUN = 12 if UP02 == 1
				replace check_deNUN = 13 if UP03 == 1
				replace check_deNUN = 14 if UP12 == 1
				replace check_deNUN = 15 if UP13 == 1
				gen str1 lst01_news = substr( lst_trans_new, 1, 1)
				gen str1 lst02_news = substr( lst_trans_new, 2, 1)
				gen str1 lst03_news = substr( lst_trans_new, 3, 1)
				gen str1 lst04_news = substr( lst_trans_new, 4, 1)
				destring  lst01_news lst02_news lst03_news lst04_news, gen(lst01_new_t lst02_new_t lst03_new_t lst04_new_t)
				forval i =1/4{
					gen lst0`i'_new = lst0`i'_new_t 
				}
				cd `current'\deNUNified
				save `first'and`fourth'm1.dta, replace
				rename serial11 serial
				keep cpsidp serial year11 month11 tm11 lst01_new lst02_new lst03_new lst04_new race sex mis11 mis12 mis13 mis14 dup fweight*
				sort cpsidp race sex mis11 dup
				save `first'_connected.dta, replace
				cd `current'
				erase `fourth'm4.dta
				erase `first'and`third'm1.dta
			}
		}
		local first=`second'
	}
	
	local tag = 1
	local first = `first1'
	while `first' <= `end' -3   {
		disp `first'
		local second = `first' + 1
		if (`first'-12)/100 == int((`first'-12)/100) {
			local second = `first' + 89
		}
		local third = `second' + 1
		if (`second'-12)/100 == int((`second'-12)/100) {
			local third = `second' + 89
		}
		local fourth = `third' + 1
		if (`third'-12)/100 == int((`third'-12)/100) {
			local fourth = `third' + 89
		}
		
		if (substr(`"`memo_data'"',`tag',6) == "`first'") {
			local tag = `tag' + 6
			*disp `tag'
			cd `current'
			use dta_files_stock\IPUMS_CPS_data_lst`first'.dta, clear
			rename mis mis11
			sort cpsidp race sex mis11
			quietly by cpsidp race sex mis11: gen dup = cond(_N==1,0,_n)
				*** Flag any duplicate records so none of them can be matched.
			sort cpsidp race sex mis11 dup
			cd `current'\deNUNified
			merge 1:1 cpsidp race sex mis11 dup using `first'_connected.dta, keepus(lst01_new)
			replace lst1_new = lst01_new
			drop lst01_new
			rename _merge _merge1
			cd `current'
			drop dup
			quietly save dta_files_stock\IPUMS_CPS_data_lst`first'.dta, replace
			
			use dta_files_stock\IPUMS_CPS_data_lst`second'.dta, clear
			rename mis mis12
			sort cpsidp race sex mis12
			quietly by cpsidp race sex mis12: gen dup = cond(_N==1,0,_n)
				*** Flag any duplicate records so none of them can be matched.
			sort cpsidp race sex mis12 dup
			cd `current'\deNUNified
			merge 1:1 cpsidp race sex mis12 dup using `first'_connected.dta, keepus(lst02_new)
			replace lst2_new = lst02_new
			drop lst02_new
			rename _merge _merge2
			cd `current'
			drop dup
			quietly save dta_files_stock\IPUMS_CPS_data_lst`second'.dta, replace
						
			use dta_files_stock\IPUMS_CPS_data_lst`third'.dta, clear
			rename mis mis13
			sort cpsidp race sex mis13
			quietly by cpsidp race sex mis13: gen dup = cond(_N==1,0,_n)
				*** Flag any duplicate records so none of them can be matched.
			sort cpsidp race sex mis13 dup
			cd `current'\deNUNified
			merge 1:1 cpsidp race sex mis13 dup using `first'_connected.dta, keepus(lst03_new)
			replace lst3_new = lst03_new
			drop lst03_new
			rename _merge _merge3
			cd `current'
			drop dup
			quietly save dta_files_stock\IPUMS_CPS_data_lst`third'.dta, replace
			
			use dta_files_stock\IPUMS_CPS_data_lst`fourth'.dta, clear
			rename mis mis14
			sort cpsidp race sex mis14
			quietly by cpsidp race sex mis14: gen dup = cond(_N==1,0,_n)
				*** Flag any duplicate records so none of them can be matched.
			sort cpsidp race sex mis14 dup
			cd `current'\deNUNified
			merge 1:1 cpsidp race sex mis14 dup using `first'_connected.dta, keepus(lst04_new)
			replace lst4_new = lst04_new
			drop lst04_new
			rename _merge _merge4
			cd `current'
			drop dup
			quietly save IPUMS_CPS_data_lst`fourth'.dta, replace
		}			

		local first=`second'
	}

	disp `"`memo_data'"'


	cd `current'
	local count = 0
	local first1=197601
	local end   =`end_sample'
	local first = `first1'
	while `first' <= `end' {
		local count = `count' + 1
		local second = `first' + 1
		if (`first'-12)/100 == int((`first'-12)/100) {
			local second = `first' + 89
		}
		clear
		use dta_files_stock\IPUMS_CPS_data_lst`first'.dta
		
		forval x =2/4 {
			local x1 = `x'-1
			replace lst`x'_new= lst`x1'_new if lst`x'_new ==.
		}
		rename lst4_new lst_new
		quietly replace lst_new=lst if lst_new ==.
		drop lst1_new lst2_new lst3_new	
		
		gen lst_detail_new = lst_new
		replace lst_detail_new = 31 if  (lst_new == 3) & (part_iv == 1) 		/* involuntary PT */
		replace lst_detail_new = 32 if  (lst_new == 3) & (part_iv == 2)			/* voluntary PT */
		quietly save `current'\dta_files_stock\IPUMS_CPS_data_lst`first'.dta, replace
		local first=`second'
	}
}



cd `current'
local count = 0
local first1=197601
local end   =`end_sample'
local first = `first1'
while `first' <= `end' {
	local count = `count' + 1
	local second = `first' + 1
	if (`first'-12)/100 == int((`first'-12)/100) {
		local second = `first' + 89
	}
	clear
	use dta_files_stock\IPUMS_CPS_data_lst`first'.dta
	noisily disp `first'
	preserve
		quietly{
			gen date = `first'
			if `IPT_VPT'==1 {
				gen str3 lfss_d = "XXX"
				replace lfss_d = "EFT" if lst_detail == 2 
				replace lfss_d = "EIP" if lst_detail == 31
				replace lfss_d = "EVP" if lst_detail == 32
				replace lfss_d = "UFT" if lst_detail == 4
				replace lfss_d = "UPT" if lst_detail == 5 
				replace lfss_d = "NNN" if lst_detail == 1
				
				sort lfss_d
				egen double status = total(fweight), by(lfss_d)
				egen double total = total(fweight)
				quietly by lfss_d:  gen duplic = cond(_N==1,0,_n)
				drop if duplic > 1
				keep date lfss_d status total		
				reshape wide status total, i(date) j(lfss_d) string
				rename totalEFT totalEF
				gen statusEP = statusEIP + statusEVP
				rename statusEFT statusEF
				rename statusUFT statusUF
				rename statusUPT statusUP
				rename statusNNN statusNN
			}
			else {
				gen str2 lfss = "XX"
				replace lfss = "EF" if lst == 2 
				replace lfss = "EP" if lst == 3
				replace lfss = "UF" if lst == 4
				replace lfss = "UP" if lst == 5 
				replace lfss = "NN" if lst == 1		
					
				sort lfss
				egen double status = total(fweight), by(lfss)
				egen double total = total(fweight)
				quietly by lfss:  gen duplic = cond(_N==1,0,_n)
				drop if duplic > 1
				keep date lfss status total		
				reshape wide status total, i(date) j(lfss) string
			}
			rename totalEF pop_xx
			drop total*
			order pop_xx, last
			gen pop = statusEF + statusEP + statusUF + statusUP + statusNN
			gen statusXX2 = pop_xx - pop
			gen rateXX = statusXX2 / pop_xx
			gen lf = statusEF + statusEP + statusUF + statusUP
			gen emp = statusEF + statusEP
			gen ump = statusUF + statusUP
			gen lf_rate = lf/pop
			gen emp_rate = emp/lf
			gen ump_rate = ump/lf
			gen fullemp_rate = statusEF/lf
			gen partemp_rate = statusEP/lf
			if `IPT_VPT'==1 {
				gen inv_partemp_rate = statusEIP/lf
				gen inv_partemp_share = statusEIP/statusEP
			}
			drop lf emp ump statusXX2 pop_xx
			rename pop total 
			gen fracEF = statusEF/total
			gen fracEP = statusEP/total
			gen fracUF = statusUF/total
			gen fracUP = statusUP/total
			gen fracNN = statusNN/total
			if `IPT_VPT'==1 {
				gen fracEIP = statusEIP/total
				gen fracEVP = statusEVP/total
			}
			drop total status*
			
			if `count' >=2 { 
				append using status.dta
				sort date
			}		
			save status.dta, replace
		}					
	restore		
	preserve
		quietly{ 
			sort mis
			egen double fw_mis = total(fweight), by(mis)
			quietly by mis:  gen duplic = cond(_N==1,0,_n)
			drop if duplic > 1
			keep mis fw_mis			
		
			gen date = `first'
			
			reshape wide fw_mis, i(date) j(mis) 
			gen fw_mis_sum = fw_mis1 + fw_mis2 + fw_mis3 + fw_mis4 + fw_mis5 + fw_mis6 + fw_mis7 + fw_mis8
			forval i = 1/8 {
				gen share_mis`i'= fw_mis`i'/fw_mis_sum
			}		
			keep date share*
			if `count' >=2 { 
				append using mis_share.dta
				sort date
			}		
			save mis_share.dta, replace
		}					
	restore	
	
	*preserve
	if `method_deNUN' == 1 {
		quietly{ 
			gen str2 lfss = "XX"
			replace lfss = "EF" if lst_new == 2 
			replace lfss = "EP" if lst_new == 3
			replace lfss = "UF" if lst_new == 4
			replace lfss = "UP" if lst_new == 5 
			replace lfss = "NN" if lst_new == 1		
				
			sort lfss
			egen double status_new_ = total(fweight), by(lfss)
			egen double total = total(fweight)
			quietly by lfss:  gen duplic = cond(_N==1,0,_n)
			drop if duplic > 1
			keep lfss status_new_* total*			
		
			gen date = `first'
			
			reshape wide status_new_ total, i(date) j(lfss) string
			rename totalEF pop_xx
			drop total*
			order pop_xx, last
			
			gen pop = status_new_EF + status_new_EP + status_new_UF + status_new_UP + status_new_NN
			gen statusXX2 = pop_xx - pop
			gen rateXX_new = statusXX2 / pop_xx
			gen lf = status_new_EF + status_new_EP + status_new_UF + status_new_UP
			gen ump = status_new_UF + status_new_UP
			gen lf_rate_new = lf/pop
			gen ump_rate_new = ump/lf
			drop lf statusXX2  pop_xx  ump 
			
			rename pop total
			gen fracEF_new = status_new_EF/total
			gen fracEP_new = status_new_EP/total
			gen fracUF_new = status_new_UF/total
			gen fracUP_new = status_new_UP/total
			gen fracNN_new= status_new_NN/total 
			
			drop status_new_* total
			if `count' >=2 { 
				append using status_new.dta
				sort date
			}		
			save status_new.dta, replace
		}
	}
	*restore
	local first=`second'
}
if `method_deNUN' == 1 {
	erase status_new.dta
}


cd `current'
local first1=197601
local end   =`end_sample'
local first = `first1'
while `first' <= `end' -1   {
	local second = `first' + 1
	if (`first'-12)/100 == int((`first'-12)/100) {
		local second = `first' + 89
	}	
	
	if `second' != `first1' {
		clear
		use dta_files_stock\IPUMS_CPS_data_lst`second'.dta		
	
		preserve
			quietly {
				keep if mis == 1| mis == 5
				*keep if age >= 16
				egen double sum_fw=total(fweight)
				collapse (sum) fweight (mean) sum_fw, by(lst)
				gen ratio_fw = fweight/sum_fw
				quietly keep ratio_fw lst
				gen date = `second'
						
				if `second' >= `first1'+2 {
					append using initial_dist_temp`first'.dta
					save initial_dist_temp`second'.dta, replace
					if (`second' == `end'){
						sort date
						order date, first
						save initial_dist.dta, replace
						keep date lst ratio_fw
						*drop if lst == -1
						replace lst = 100 if lst ==.
						reshape wide ratio_fw, i(date) j(lst) 
						save initial_dist_wide.dta, replace
						erase initial_dist_temp`second'.dta
					}
					erase initial_dist_temp`first'.dta
				}
				else {
					save initial_dist_temp`second'.dta, replace
				}
			}
		restore	
		

		drop if mis==1 | mis == 5
		local count2 = _N
		quietly {
			rename mis mis1
			rename lst lst1
			if `IPT_VPT'==1 {
				rename lst_detail lst1_detail
			}
			if `method_deNUN' == 1 {
				rename lst_new lst_new1
			}
			rename fweight fweight1
			rename ind ind1
			if `second'>= 199401 {
				rename uhrsworkt hrusl1
				rename ahrsworkt hract1
				rename samejob samejob1
				rename numjob numjob1
			}
			gen mis0 = mis1 - 1
		}
		sort cpsidp race sex mis0
		quietly by cpsidp race sex mis0: gen dup = cond(_N==1,0,_n)
			*** Flag any duplicate records so none of them can be matched.
		sort cpsidp race sex mis0 dup
		save `second', replace

		clear
		use dta_files_stock\IPUMS_CPS_data_lst`first'
		
		preserve
			quietly {
				keep if mis == 4| mis == 8
				*keep if age >= 16
				egen double sum_fw=total(fweight)
				collapse (sum) fweight (mean) sum_fw, by(lst)
				gen ratio_fw = fweight/sum_fw
				quietly keep ratio_fw lst
				gen date = `first'
			
				if `first' >= `first1'+1 {
					append using terminal_dist_temp`f1'.dta
					save terminal_dist_temp`first'.dta, replace
					if (`first' == `end'-1){
						sort date
						order date, first
						save termial_dist.dta, replace
						keep date lst ratio_fw
						*drop if lst == -1
						replace lst = 100 if lst ==.
						reshape wide ratio_fw, i(date) j(lst) 
						save terminal_dist_wide.dta, replace
						erase terminal_dist_temp`first'.dta
					}
					erase terminal_dist_temp`f1'.dta
				}
				else {
					save terminal_dist_temp`first'.dta, replace
				}
			}
		restore	
		
		drop if mis == 4 | mis == 8
		local count1 = _N
		quietly{
			rename mis mis0
			*rename edu edu1
			rename lst lst0
			if `IPT_VPT'==1 {
				rename lst_detail lst0_detail
			}
			if `method_deNUN' == 1 {
				rename lst_new lst_new0
			}
			rename fweight fweight0
			rename ind ind0
			*rename occ occ0
			if `first'>= 199401 {
				rename uhrsworkt hrusl0
				rename ahrsworkt hract0
				rename samejob samejob0
				rename numjob numjob0
			}

			sort cpsidp race sex mis0
			quietly by cpsidp race sex mis0: gen dup = cond(_N==1,0,0-_n)
			   *** Flag any duplicate records with a negative number so none of them can be matched
			sort cpsidp race sex mis0 dup
			merge cpsidp race sex mis0 dup using `second'

			rename _merge _merge01
			order mis1, after(mis0) 
			order fweight1, after(fweight0) 
			order ind1, after(ind0)
			if `IPT_VPT'==1 {
				order lst0_detail, after(lst0)
				order lst1_detail, after(lst1)
			}
			if `method_deNUN' == 1 {
				order lst_new0, after(lst0)
				order lst_new1, after(lst1)
			}
			if `first'>= 199401 {
				order numjob1, after(numjob0) 
			}
		}
		save dta_files_stock\merge`second'.dta, replace
		   *** This creates a record of all individuals, matched if they agree on cpsidp, race, and sex. And also neither record can be duplicated.
		erase `second'.dta	

		quietly{
			gen count1 = 1 if _merge01 == 1 | _merge01 == 3
			gen count2 = 1 if _merge01 == 2 | _merge01 == 3
			sum count1 count2
		}
		display `count1'
		display `count2'
	}
	local f1 = `first'
	local first=`second'
}


clear
cd `current'
capture mkdir figure_state
capture mkdir figure_flows
local first=197601
local end  =`end_sample'
local x=`first'
while `x' <=`end'  {
	quietly{
		if `x' != `first' {
			forval i =1/2 {
				use dta_files_stock\merge`x', replace
				*keep if age >= 16
				
				if `i'== 1{
					gen match = 0
					replace match = 1 if _merge01 == 3
					egen matchrate = wtmean(match), weight(fweight0)
					preserve
						sort match
						quietly by match:  gen duplic = cond(_N==1,0,_n)
						drop if duplic > 1
						drop if match == 1
						keep matchrate 
						noisily disp `x' matchrate 
						gen date = `x'
						if `x' >= `first'+2 {
							append using matchrate_temp`x1'.dta
							save matchrate_temp`x'.dta, replace
							if `x' == `end' {
								sort date
								gen str4 year=substr(string(date),1,4)
								gen str2 month=substr(string(date),5,6)
								gen year_n = real(year)
								gen month_n = real(month)
								gen survey = ym(year_n, month_n)
								order survey, after(date)
								tsset survey, monthly
								drop year month year_n month_n
								order survey, first
								save matchrate.dta, replace
								erase matchrate_temp`x'.dta
							}
							erase matchrate_temp`x1'.dta
						}
						else {
							save matchrate_temp`x'.dta, replace
						}
					restore
				}
			
				if `x' != 197701 & `x' != 197702 & `x' != 197705 & `x' != 197707 & `x' != 197708 & `x' != 197709 & `x' != 197709 & `x' != 197710 & `x' != 197711 & `x' != 197712 & `x'!= 198507 & `x'!= 198510 & `x' != 199506 & `x' != 199507 & `x' != 199508 & `x' != 199509 {
					if `i'== 1{
						gen str2 lfss0 = "XX"
						replace lfss0 = "EF" if lst0 == 2 
						replace lfss0 = "EP" if lst0 == 3
						replace lfss0 = "UF" if lst0 == 4
						replace lfss0 = "UP" if lst0 == 5 
						replace lfss0 = "NN" if lst0 == 1
						gen str2 lfss1 = "XX"
						replace lfss1 = "EF" if lst1 == 2 
						replace lfss1 = "EP" if lst1 == 3
						replace lfss1 = "UF" if lst1 == 4
						replace lfss1 = "UP" if lst1 == 5
						replace lfss1 = "NN" if lst1 == 1
						if `IPT_VPT'==1 {
							preserve
							gen str3 lfss0_d = "XXX"
							replace lfss0_d = "EFT" if lst0_detail == 2 
							replace lfss0_d = "EIP" if lst0_detail == 31
							replace lfss0_d = "EVP" if lst0_detail == 32
							replace lfss0_d = "UFT" if lst0_detail == 4
							replace lfss0_d = "UPT" if lst0_detail == 5 
							replace lfss0_d = "NNN" if lst0_detail == 1
							gen str3 lfss1_d = "XXX"
							replace lfss1_d = "EFT" if lst1_detail == 2 
							replace lfss1_d = "EIP" if lst1_detail == 31
							replace lfss1_d = "EVP" if lst1_detail == 32
							replace lfss1_d = "UFT" if lst1_detail == 4
							replace lfss1_d = "UPT" if lst1_detail == 5 
							replace lfss1_d = "NNN" if lst1_detail == 1
							
							gen str6 lfss2_d = lfss0_d + lfss1_d
							sort lfss2_d
							replace fweight0 = 0 if fweight0 == .
							replace fweight1 = 0 if fweight1 == .
							gen weight = (fweight0+fweight1)/2
							
							by lfss2_d: gen double flows_temp = sum(weight)
							egen double flows = max(flows_temp), by(lfss2_d)
							drop flows_temp
							replace flows = flows/1000000
							
							sort lfss2_d
							quietly by lfss2_d:  gen duplic = cond(_N==1,0,_n)
							drop if duplic > 1
							keep lfss2_d flows
							
							gen date = `x'
							reshape wide flows, i(date) j(lfss2_d) string
														
							isvar flowsEFTEFT flowsEFTEIP flowsEFTEVP flowsEFTUFT flowsEFTUPT flowsEFTNNN	/*
							*/ flowsEIPEFT flowsEIPEIP flowsEIPEVP flowsEIPUFT flowsEIPUPT flowsEIPNNN /*
							*/ flowsEVPEFT flowsEVPEIP flowsEVPEVP flowsEVPUFT flowsEVPUPT flowsEVPNNN /*
							*/ flowsUFTEFT flowsUFTEIP flowsUFTEVP flowsUFTUFT flowsUFTUPT flowsUFTNNN /*
							*/ flowsUPTEFT flowsUPTEIP flowsUPTEVP flowsUPTUFT flowsUPTUPT flowsUPTNNN /* 
							*/ flowsNNNEFT flowsNNNEIP flowsNNNEVP flowsNNNUFT flowsNNNUPT flowsNNNNNN   
							local y = r(badlist)
							gen new = 0
							capture rename new `y'
							if _rc ==198 {
								drop new
							}
							gen sum_flows_from_EFT = flowsEFTEFT + flowsEFTEIP + flowsEFTEVP + flowsEFTUFT + flowsEFTUPT + flowsEFTNNN
							gen sum_flows_from_EIP = flowsEIPEFT + flowsEIPEIP + flowsEIPEVP + flowsEIPUFT + flowsEIPUPT + flowsEIPNNN
							gen sum_flows_from_EVP = flowsEVPEFT + flowsEVPEIP + flowsEVPEVP + flowsEVPUFT + flowsEVPUPT + flowsEVPNNN
							gen sum_flows_from_UFT = flowsUFTEFT + flowsUFTEIP + flowsUFTEVP + flowsUFTUFT + flowsUFTUPT + flowsUFTNNN
							gen sum_flows_from_UPT = flowsUPTEFT + flowsUPTEIP + flowsUPTEVP + flowsUPTUFT + flowsUPTUPT + flowsUPTNNN
							gen sum_flows_from_NNN = flowsNNNEFT + flowsNNNEIP + flowsNNNEVP + flowsNNNUFT + flowsNNNUPT + flowsNNNNNN
							local status_names "EFT EIP EVP UFT UPT NNN"
							foreach z of local status_names {
								foreach y of local status_names {
									gen flow`z'`y' = flows`z'`y'/sum_flows_from_`z'
								}
							}
							save `current'\dta_files_stock\temp_wideflows_detail`x'.dta, replace
							drop flows* sum*
							if `x' >= `first'+2 {
								append using flows_detail
							}
							save flows_detail.dta, replace
							restore
						}
					}
					else{
						if `method_deNUN' == 0 {
							gen lst_new0 = lst0
							gen lst_new1 = lst1
						}
						gen str2 lfss0 = "XX"
						replace lfss0 = "EF" if lst_new0 == 2 
						replace lfss0 = "EP" if lst_new0 == 3
						replace lfss0 = "UF" if lst_new0 == 4
						replace lfss0 = "UP" if lst_new0 == 5 
						replace lfss0 = "NN" if lst_new0 == 1
						gen str2 lfss1 = "XX"
						replace lfss1 = "EF" if lst_new1 == 2 
						replace lfss1 = "EP" if lst_new1 == 3
						replace lfss1 = "UF" if lst_new1 == 4
						replace lfss1 = "UP" if lst_new1 == 5
						replace lfss1 = "NN" if lst_new1 == 1
					}
					
					gen str4 lfss2 = lfss0 + lfss1				
					sort lfss2
					replace fweight0 = 0 if fweight0 == .
					replace fweight1 = 0 if fweight1 == .
					gen weight = (fweight0+fweight1)/2
					
					*egen double flows = total(weight), by(lfss2)
				
					by lfss2: gen double flows_temp = sum(weight)
					egen double flows = max(flows_temp), by(lfss2)
					drop flows_temp
					replace flows = flows/1000000
					save dta_files_stock\merge_plus`x'.dta, replace
					
					if `i'== 1{
						if `x'>=199402 {
							gen dif_numjob = numjob1 - numjob0
							preserve
							keep if lfss2 == "EFEP"|lfss2 == "EPEF"
							keep  lfss2 sex age age_cl weight samejob1 numjob1 numjob0 dif_numjob self agri ind0 ind1
							order numjob0, after(weight)
							order numjob1, after(numjob0)
							order weight, first
							order age, after(sex)
							order age_cl, after(age)
							order ind1, after(ind0)
							gen dif_ind = ind0-ind1
							replace dif_ind = abs(dif_ind)
							replace samejob1 = 2 if samejob1 == -1 & dif_ind>0
							replace samejob1 = 5 if samejob1 == -1
							gen samejob_detail = samejob1
							replace samejob_detail = 3 if samejob1 == 1 & agri == 1
							replace samejob_detail = 4 if samejob1 == 1 & self == 1
							replace samejob_detail = 6 if abs(dif_numjob) > 0
							label define samejob_str 1 "Yes" 2 "No" 3 "Yes, but agriculture" 4 "Yes, but self-employed" 5 "Not answered" 6 "Change the number of jobs"
							label values samejob_detail samejob_str
							save `current'\dta_files_stock\FPmove`x'.dta, replace				
							drop if samejob1 < -1
							egen double fsamejob = total(weight), by(samejob_detail)
							sort samejob_detail

							quietly by samejob_detail:  gen duplic = cond(_N==1,0,_n)
							drop if duplic > 1
							keep samejob_detail fsamejob
							gen date = `x'
							reshape wide fsamejob, i(date) j(samejob_detail)
							if `x' != 199403 {				
								forvalues f = 1/6 {
									gen frac_samejob`f' = fsamejob`f'/(fsamejob1+fsamejob2+fsamejob3+fsamejob4+fsamejob5+fsamejob6)
								}
							}
							else {
								drop fsamejob*
								forvalues f = 1/6 {
									gen frac_samejob`f' = 0
								}
								replace frac_samejob5 = 1
							}
								
							gen str4 year=substr(string(date),1,4)
							gen str2 month=substr(string(date),5,6)
							gen year_n = real(year)
							gen month_n = real(month)
							gen survey = ym(year_n, month_n)
							order survey, after(date)

							drop year month year_n month_n
							
							if `x' >= 199403 {
								append using jobchange.dta
								if `x' == `end' {
									sort survey
									quietly by survey:  gen duplic = cond(_N==1,0,_n)
									drop if duplic > 1
									drop duplic
									tsset survey, monthly
								}						
							}
							save jobchange.dta, replace
							restore	
						}
					}
				
					sort lfss2
					quietly by lfss2:  gen duplic = cond(_N==1,0,_n)
					drop if duplic > 1
					keep lfss2 flows
					
					gen date = `x'
					reshape wide flows, i(date) j(lfss2) string					

					isvar flowsEFEF flowsEFEP flowsEFUF flowsEFUP flowsEFNN flowsEPEF flowsEPEP flowsEPUF flowsEPUP flowsEPNN /*
							*/ flowsUFEF flowsUFEP flowsUFUF flowsUFUP flowsUFNN flowsUPEF flowsUPEP flowsUPUF flowsUPUP flowsUPNN /*
							*/ flowsNNEF flowsNNEP flowsNNUF flowsNNUP flowsNNNN  
					local y = r(badlist)
					gen new = 0
					capture rename new `y'
					if _rc ==198 {
						drop new
					}					
						
					gen flowEFEF = flowsEFEF/(flowsEFEF+flowsEFEP+flowsEFUF+flowsEFUP+flowsEFNN)
					gen flowEFEP = flowsEFEP/(flowsEFEF+flowsEFEP+flowsEFUF+flowsEFUP+flowsEFNN)
					gen flowEFUF = flowsEFUF/(flowsEFEF+flowsEFEP+flowsEFUF+flowsEFUP+flowsEFNN)
					gen flowEFUP = flowsEFUP/(flowsEFEF+flowsEFEP+flowsEFUF+flowsEFUP+flowsEFNN)
					gen flowEFNN = flowsEFNN/(flowsEFEF+flowsEFEP+flowsEFUF+flowsEFUP+flowsEFNN)
					gen flowEPEF = flowsEPEF/(flowsEPEF+flowsEPEP+flowsEPUF+flowsEPUP+flowsEPNN)
					gen flowEPEP = flowsEPEP/(flowsEPEF+flowsEPEP+flowsEPUF+flowsEPUP+flowsEPNN)
					gen flowEPUF = flowsEPUF/(flowsEPEF+flowsEPEP+flowsEPUF+flowsEPUP+flowsEPNN)
					gen flowEPUP = flowsEPUP/(flowsEPEF+flowsEPEP+flowsEPUF+flowsEPUP+flowsEPNN)
					gen flowEPNN = flowsEPNN/(flowsEPEF+flowsEPEP+flowsEPUF+flowsEPUP+flowsEPNN)
					gen flowUFEF = flowsUFEF/(flowsUFEF+flowsUFEP+flowsUFUF+flowsUFUP+flowsUFNN)
					gen flowUFEP = flowsUFEP/(flowsUFEF+flowsUFEP+flowsUFUF+flowsUFUP+flowsUFNN)
					gen flowUFUF = flowsUFUF/(flowsUFEF+flowsUFEP+flowsUFUF+flowsUFUP+flowsUFNN)
					gen flowUFUP = flowsUFUP/(flowsUFEF+flowsUFEP+flowsUFUF+flowsUFUP+flowsUFNN)
					gen flowUFNN = flowsUFNN/(flowsUFEF+flowsUFEP+flowsUFUF+flowsUFUP+flowsUFNN)
					gen flowUPEF = flowsUPEF/(flowsUPEF+flowsUPEP+flowsUPUF+flowsUPUP+flowsUPNN)
					gen flowUPEP = flowsUPEP/(flowsUPEF+flowsUPEP+flowsUPUF+flowsUPUP+flowsUPNN)
					gen flowUPUF = flowsUPUF/(flowsUPEF+flowsUPEP+flowsUPUF+flowsUPUP+flowsUPNN)
					gen flowUPUP = flowsUPUP/(flowsUPEF+flowsUPEP+flowsUPUF+flowsUPUP+flowsUPNN)
					gen flowUPNN = flowsUPNN/(flowsUPEF+flowsUPEP+flowsUPUF+flowsUPUP+flowsUPNN)
					gen flowNNEF = flowsNNEF/(flowsNNEF+flowsNNEP+flowsNNUF+flowsNNUP+flowsNNNN)
					gen flowNNEP = flowsNNEP/(flowsNNEF+flowsNNEP+flowsNNUF+flowsNNUP+flowsNNNN)
					gen flowNNUF = flowsNNUF/(flowsNNEF+flowsNNEP+flowsNNUF+flowsNNUP+flowsNNNN)
					gen flowNNUP = flowsNNUP/(flowsNNEF+flowsNNEP+flowsNNUF+flowsNNUP+flowsNNNN)
					gen flowNNNN = flowsNNNN/(flowsNNEF+flowsNNEP+flowsNNUF+flowsNNUP+flowsNNNN)
					gen total = flowsEFEF+flowsEFEP+flowsEFUF+flowsEFUP+flowsEFNN + flowsEPEF+flowsEPEP+flowsEPUF+flowsEPUP+flowsEPNN /*
					*/ + flowsUFEF+flowsUFEP+flowsUFUF+flowsUFUP+flowsUFNN + flowsUPEF+flowsUPEP+flowsUPUF+flowsUPUP+flowsUPNN /*
					*/ + flowsNNEF+flowsNNEP+flowsNNUF+flowsNNUP+flowsNNNN
				}	    
				else {
					clear
					set obs 1
					gen date = `x'
					local status_names1 "EF EP UF UP NN"
					foreach z of local status_names1 {
						foreach y of local status_names1 {
							gen flow`z'`y' = .
						}
					}
					gen total = .
					if `x' > 199401 {
						preserve
						forvalues f = 1/6 {
							gen frac_samejob`f' = 0
						}
						replace frac_samejob5 = 1
						
						gen str4 year=substr(string(date),1,4)
						gen str2 month=substr(string(date),5,6)
						gen year_n = real(year)
						gen month_n = real(month)
						gen survey = ym(year_n, month_n)
						order survey, after(date)
						keep date survey frac_samejob*						
						append using jobchange.dta	
						save jobchange.dta, replace
						restore
					}	
					if (`IPT_VPT'==1) & (`i'== 1)  {
						preserve
						clear
						set obs 1
						gen date = `x'
						local status_names2 "EFT EIP EVP UFT UPT NNN"
						foreach z of local status_names2 {
							foreach y of local status_names2 {
								gen flow`z'`y' = .
							}
						}
						save `current'\dta_files_stock\temp_wideflows_detail`x'.dta, replace
						append using flows_detail
						save flows_detail.dta, replace
						restore
					}
				
				}
				if `x' >= `first'+2 {
					if (`i'==1) {
						append using flows
					}
					else {
						append using flows_new
					}
				}
				if `x' == `end' {
					gen str4 year=substr(string(date),1,4)
					gen str2 month=substr(string(date),5,6)
					gen year_n = real(year)
					gen month_n = real(month)
					gen survey = ym(year_n, month_n)
					order survey, after(date)
					tsset survey, monthly
					drop year month year_n month_n
					gen emp = flowsEFEF+flowsEFEP+flowsEFUF+flowsEFUP+flowsEFNN + flowsEPEF+flowsEPEP+flowsEPUF+flowsEPUP+flowsEPNN
					gen nlf = flowsEFEF+flowsEFEP+flowsEFUF+flowsEFUP+flowsEFNN + flowsEPEF+flowsEPEP+flowsEPUF+flowsEPUP+flowsEPNN /*
						  */+ flowsUFEF+flowsUFEP+flowsUFUF+flowsUFUP+flowsUFNN + flowsUPEF+flowsUPEP+flowsUPUF+flowsUPUP+flowsUPNN
					gen part = flowsEPEF+flowsEPEP+flowsEPUF+flowsEPUP+flowsEPNN
					gen full = flowsEFEP+flowsEFEP+flowsEFUF+flowsEFUP+flowsEFNN
					gen net_promotion = (flowsEPEF-flowsEFEP)/part
					gen promotion_rate = flowsEPEF/part
					gen demotion_rate = flowsEFEP/full
					gen frac_ftpt = (flowsEFEP + flowsEPEF)/emp
					gen frac_fp = (flowsEFEP)/emp
					gen frac_pf = (flowsEPEF)/emp
					gen frac_ftpt2 = (flowsEFEP + flowsEPEF)/nlf
					gen frac_fp2 = (flowsEFEP)/nlf
					gen frac_pf2 = (flowsEPEF)/nlf
					gen net_ftpt = frac_fp2 - frac_pf2
					drop part full nlf emp
				}
				if (`i'==1) {
					save flows.dta, replace
				}
				else {
					save flows_new.dta, replace
				}				
			}
		}
	}
	local x1 = `x'
	local x = `x' + 1
	if (`x'-13)/100 == int((`x'-13)/100) {
		local x = `x' + 88
		noisily display (`x'-1)/100
	}
}


* drop FPmover with small hours adjustment
clear
cd `current'
local first=199601
local end  =`end_sample'
local x=`first'
log using dta_files_stock\hours_adhustments_by_FPmover, replace
while `x' <=`end'  {
	quietly{
		use dta_files_stock\merge_plus`x'.dta, replace
		drop if fweight0 == . | fweight1 == .
		keep if lfss2 == "EFEP"|lfss2 == "EPEF"
		keep year month sex age age_cl weight self agri lfss2  hrusl0  hrusl1 hract0 hract1 ind0 
		replace hract0 =  hrusl0 if hract0 == 999
		replace hract1 =  hrusl1 if hract1 == 999
		order weight, after(age_cl)
		order ind0, after(weight)
		order hrusl0, before(hrusl1)
		order hract0, before(hrusl1)
		order hract1, before(lfss2)
		gen dif_uhours =.
		gen dif_ahours =. 
		replace dif_uhours=hrusl1-hrusl0
		replace dif_ahours=hract1-hract0  if (hract1 < 100 & hract0 < 100)
		replace dif_uhours=999 if (hrusl1 ==997 | hrusl0 ==997)
		gen dif_hours = dif_uhours
		replace dif_hours = dif_ahours if dif_uhours==999
		replace dif_hours = 999 if  dif_hours ==.
		noisily tabulate lfss2 [aw= weight] if dif_hours <999, sum( dif_hours) mean   not
		drop if  dif_hours ==999
		gen ind_small_adjs5 = 0
		gen ind_small_adjs7 = 0
		replace ind_small_adjs5 = 1 if (dif_hours <= 5 & lfss2 == "EPEF") | (dif_hours >= -5 & lfss2 == "EFEP")
		replace ind_small_adjs7 = 1 if (dif_hours <= 7 & lfss2 == "EPEF") | (dif_hours >= -7 & lfss2 == "EFEP")
		save dta_files_stock\FPmover_detail`x'.dta, replace
		egen double tw = total(weight), by(lfss2)
		egen double fw5 = total(weight), by( ind_small_adjs5  lfss2 )
		egen double fw7 = total(weight), by( ind_small_adjs7  lfss2 )
		gen double fw5s = fw5/tw
		gen double fw7s = fw7/tw
		tostring ind_small_adjs5, replace
		tostring ind_small_adjs7, replace
		gen lfss2_ind5 = lfss2 + ind_small_adjs5 
		gen lfss2_ind7 = lfss2 + ind_small_adjs7 
		
		sort lfss2_ind5
		by lfss2_ind5:  gen duplic5 = cond(_N==1,0,_n)
		sort lfss2_ind7
		by lfss2_ind7:  gen duplic7 = cond(_N==1,0,_n)
		preserve
		drop if duplic5 > 1
		keep fw5s lfss2_ind5
		gen date = `x'
		reshape wide fw5s, i(date) j(lfss2_ind5) string	
		if (`x' > `first') {
			append using dta_files_stock\temp_FP.dta
		}
		sort date	
		save dta_files_stock\temp_FP.dta, replace
		restore
		drop if duplic7 > 1
		keep fw7s lfss2_ind7
		gen date = `x'
		reshape wide fw7s, i(date) j(lfss2_ind7) string	
		if (`x' > `first') {
			append using dta_files_stock\temp_FP2.dta
		}
		sort date	
		save dta_files_stock\temp_FP2.dta, replace
	}	
	local x1 = `x'
	local x = `x' + 1
	if (`x'-13)/100 == int((`x'-13)/100) {
		local x = `x' + 88
		noisily display (`x'-1)/100
	}
}
log close 
quietly{
clear 
	use dta_files_stock\temp_FP.dta, replace
	merge date using dta_files_stock\temp_FP2.dta
	keep fw5sEFEP1 fw5sEPEF1  fw7sEFEP1 fw7sEPEF1
	save dta_files_stock\small_hrs_adj_FP.dta, replace
	erase dta_files_stock\temp_FP.dta
	erase dta_files_stock\temp_FP2.dta
}
log using FPmove_small_adjustments, replace
sum
log close



* keep below


cd `current'
use flows.dta, clear
egen ump = rowtotal(flowsUFEF flowsUFEP flowsUFUF flowsUFUP flowsUPEF flowsUPEP flowsUPUF flowsUPUP)
gen migration_rate = (flowsUFUP + flowsUPUF)/ump
outsheet date migration_rate using migration_rate.csv, comma replace
export excel date migration_rate using migration_rate, replace

keep if (date >= 199402 & date <= `end_sample')
outsheet date migration_rate using migration_rate_1994_2018.csv, comma replace
export excel date migration_rate using migration_rate_1994_2018, replace


cd `current'
use flows.dta, clear
drop flows*
keep date flow* frac_fp2 frac_pf2 net_ftpt net_promotion promotion_rate demotion_rate
save flow_probability.dta, replace
outsheet date flow* using flow_probability.csv, comma replace
export excel date flow* using flow_probability, replace
outsheet date frac_fp2 frac_pf2 net_ftpt using flow_ftpt.csv, comma replace
export excel date frac_fp2 frac_pf2 net_ftpt using flow_ftpt, replace
outsheet date net_promotion using flow_netpromotion.csv, comma replace
export excel date net_promotion using flow_promotion, replace
outsheet date promotion_rate demotion_rate using promotion_rate.csv, comma replace
export excel date promotion_rate demotion_rate using promotion_rate, replace
keep if (date >= 197902 & date <= `end_sample')
outsheet date flow* using flow_probability_1979_2018.csv, comma replace
keep if (date >= 199402 & date <= `end_sample')
outsheet date promotion_rate demotion_rate using promotion_rate_1994_2018.csv, comma replace
export excel date promotion_rate demotion_rate using promotion_rate_1994_2018, replace

if `IPT_VPT'==1	{
	cd `current'
	use flows_detail.dta, clear
	sort date
	save flow_probability_detail.dta, replace
	outsheet date flow* using flow_probability_detail.csv, comma replace
	export excel date flow* using flow_probability_detail, replace
	keep if (date >= 197902 & date <= `end_sample')
	outsheet date flow* using flow_probability_detail_1979_2018.csv, comma replace
}

if `method_deNUN' == 1 {
	cd `current'
	use flows_new.dta, clear
	drop flows*
	keep date flow* frac_fp2 frac_pf2 net_ftpt net_promotion promotion_rate demotion_rate
	cd `current'\deNUNified
	capture mkdir results
	cd `current'\deNUNified\results
	save flow_new_probability.dta, replace
	outsheet date flow* using flow_new_probability.csv, comma replace
	export excel date flow* using flow_new_probability, replace
	outsheet date frac_fp2 frac_pf2 net_ftpt using flow_new_ftpt.csv, comma replace
	export excel date frac_fp2 frac_pf2 net_ftpt using flow_new_ftpt, replace
	outsheet date net_promotion using flow_new_netpromotion.csv, comma replace
	export excel date net_promotion using flow_new_promotion, replace
	outsheet date promotion_rate demotion_rate using promotion_rate_new.csv, comma replace
	export excel date promotion_rate demotion_rate using promotion_rate_new, replace
	keep if (date >= 199402 & date <= `end_sample')
	outsheet date promotion_rate demotion_rate using promotion_rate_new_1994_2018.csv, comma replace
	export excel date promotion_rate demotion_rate using promotion_rate_new_1994_2018, replace
}


cd `current'
use matchrate.dta, clear
twoway (line matchrate survey, lpattern(solid)  lwidth(medthick)), graphregion(color(white)) xtitle("") title("Matching rate", span)
cd `current'\figure_state
graph export match_rate.eps, as(eps) replace




cd `current'
use status.dta, clear
quietly{
	gen str4 year=substr(string(date),1,4)
	gen str2 month=substr(string(date),5,6)
	gen year_n = real(year)
	gen month_n = real(month)
	gen survey = ym(year_n, month_n)
	order survey, after(date)
	tsset survey, monthly
}

cd `current'\figure_state
twoway (area fracNN survey, color(gray))  (area fracUP survey, color(navy))  (area fracUF survey, color(edkblue))  (area fracEP survey, color(eltblue))  (area fracEF survey, color(green))/*
*/, graphregion(color(white))  yscale(range(0.0 1.0)) ylabel(0.0(0.1)1.0) xtitle("") title("Employment Status", span)/*
*/ legend(lab(1 "NLF") lab(2 "UP") lab(3 "UF") lab(4 "EP") lab(5 "EF") rows(1))
graph export emp_status.eps, as(eps) replace
graph export emp_status.png, as(png) replace
twoway (line lf_rate survey, lpattern(solid) lwidth(thick)), graphregion(color(white))  yscale(range(0.6 0.7)) ylabel(0.6(0.02)0.7) xtitle("") title("Participation Rate", span)
graph export labor_force_rate.eps, as(eps) replace
graph export labor_force_rate.png, as(png) replace
twoway (line ump_rate survey, lpattern(solid) lwidth(thick)), graphregion(color(white)) yscale(range(0 0.12)) ylabel(0.0(0.02)0.12) xtitle("") title("Unemployment Rate", span)
graph export ump_rate.eps, as(eps) replace
graph export ump_rate.png, as(png) replace
twoway (line fullemp_rate survey, lpattern(solid) lwidth(thick)), graphregion(color(white)) yscale(range(0.6 0.8)) ylabel(0.6(0.05)0.80) xtitle("")  title("Full-time employment/labor force", span)
graph export fulltime_rate.eps, as(eps) replace
graph export fulltime_rate.png, as(png) replace
twoway (line partemp_rate survey, lpattern(solid) lwidth(thick)), graphregion(color(white)) yscale(range(0.1 0.26)) ylabel(0.1(0.05)0.25) xtitle("")  title("Part-time employment/labor force", span)
graph export parttime_rate.eps, as(eps) replace
graph export parttime_rate.png, as(png) replace
outsheet date fracEF fracEP fracUF fracUP fracNN using emp_status.csv , comma replace
cd `current'
export excel date fracEF fracEP fracUF fracUP fracNN using emp_status, replace
save emp_status, replace
if `IPT_VPT'==1	{
	cd `current'\figure_state
	twoway (line partemp_rate survey, lpattern(solid) lwidth(thick))  (line inv_partemp_rate survey, lpattern(solid) lwidth(thick)) /*
*/  ,graphregion(color(white)) yscale(range(0.1 0.26)) ylabel(0.1(0.05)0.25) xtitle("")  title("Part-time employment/labor force", span) /*
*/  legend(lab(1 "Total PT") lab(2 "Involuntary PT") rows(1))	
	graph export involuntary_parttime_rate.eps, as(eps) replace
	graph export involuntary_parttime_rate.png, as(png) replace
	outsheet date fracEF fracEIP fracEVP fracUF fracUP fracNN using emp_status_detail.csv , comma replace
	cd `current'
	export excel date fracEF fracEIP fracEVP fracUF fracUP fracNN using emp_status_detail, replace
	rename fracEF fracEFT
	rename fracUF fracUFT
	rename fracUP fracUPT
	rename fracNN fracNNN
	save emp_status_detail, replace
	gen PT_to_E_rate = (fracEIP+fracEVP)/(fracEF+fracEIP+fracEVP)
	gen IPT_to_E_rate = fracEIP/(fracEF+fracEIP+fracEVP)
	gen IPT_to_PT_rate = fracEIP/(fracEIP+fracEVP)
	export excel date PT_to_E_rate IPT_to_E_rate IPT_to_PT_rate  using PT_to_Employment, replace
}


cd `current'
use jobchange.dta, clear
tsset survey, monthly
quietly{
	gen agri = frac_samejob1 + frac_samejob3
	gen self = frac_samejob1 + frac_samejob3 + frac_samejob4
	gen max_samejop = frac_samejob1 + frac_samejob3 + frac_samejob4 + frac_samejob5
	gen num_change = max_samejop + frac_samejob6
	gen total = num_change + frac_samejob2 
	rename frac_samejob1 min_samejop
}
cd `current'\figure_flows
*twoway (line frac_samejob5 survey, lpattern(solid) lc(black) lwidth(medium)) 
twoway (parea total survey, sort pattern(pattern9)) /*  *twoway (area total survey, color(stone))
*/ (parea num_change survey, fcolor(ebblue) sort pattern(pattern6) lc(black)) (parea max_samejop survey, sort pattern(pattern10) fcolor(gray) lc(black)) /*
*/ (parea self survey, fcolor(khaki) sort pattern(pattern1) lc(black)) (parea agri survey, lpattern(dashed) lw(thin) fcolor(midgreen) sort pattern(pattern1) lc(black)) (parea min_samejop survey, lpattern(dashed) lw(thin) fcolor(midgreen) sort pattern(pattern1) lc(black)) /*
*/ , graphregion(color(white)) yscale(range(0.0 1.0)) ylabel(0.0(0.2)1.0)  /*
*/ legend(lab(1 "change their jobs") lab(2 "change the number of jobs") lab(3 "Not answered") lab(4 "Same, but self-employed") lab(5 "Same, but agriculture") lab(6 "stay at the same company") /*
*/ rows(5)) 
graph export jobchange_FTPT2.eps, as(eps) replace
graph export jobchange_FTPT2.png, as(png) replace




cd `current'\figure_flows
twoway  (parea total survey, sort pattern(pattern9)) /*
*/ (parea num_change survey, fcolor(ebblue) sort pattern(pattern6) lc(black)) /*
*/ (parea max_samejop survey, sort pattern(pattern10) fcolor(gray) lc(black)) /*
*/ (parea self survey, sort pattern(pattern1) lpattern(dashed) fcolor(green) lc(black)), graphregion(color(white)) yscale(range(0.0 1.0)) ylabel(0.0(0.2)1.0)  /*
*/ legend(lab(1 "jobs change") lab(2 "change the number of jobs") lab(3 "Not answered") lab(4 "Within the same firm") rows(2)) 
graph export jobchange_FTPT3.eps, as(eps) replace
graph export jobchange_FTPT3.png, as(png) replace

outsheet survey total num_change max_samejop self using D:\CPS\IPUMS_CPS_until2018\figure_flows\ftpt.csv, comma replace


cd `current'
use report_usual_hours.dta, clear
tsset survey, monthly
cd `current'\figure_state
twoway (line prob_fw_report1 survey, lpattern(solid) lwidth(thick)), graphregion(color(white)) yscale(range(0.0 1.0)) ylabel(0.0(0.1)1.0) xtitle("")  title("Reporting Usual Hours Worked", span)
graph export report_uhs_rate.eps, as(eps) replace
graph export report_uhs_rate.png, as(png) replace

cd `current'
use rate_drop_emp.dta, clear
tsset survey, monthly
cd `current'\figure_state
twoway (line prob_fw_drop_emp0 survey, lpattern(solid) lwidth(thick)), graphregion(color(white)) yscale(range(0.0 1.0)) ylabel(0.0(0.1)1.0) xtitle("")  title("Not Dropped from Employment", span)
graph export rate_drop_emp.eps, as(eps) replace
graph export rate_drop_emp.png, as(png) replace



cd `current'
use flows.dta, clear
cd `current'\figure_flows
twoway (line flowEFEF survey, lpattern(solid) lwidth(thick)) (line flowEFEP survey, lpattern(solid) lwidth(thick)) /*
*/ (line flowEFUF survey, lpattern(solid) lwidth(thick)) (line flowEFUP survey, lpattern(solid) lwidth(thick)) /*
*/ (line flowEFNN survey, lpattern(solid) lwidth(thick)) ,graphregion(color(white)) yscale(range(0.0 1.0)) ylabel(0.0(0.2) 1.0)  title("Flows_fromEFtoXX", span) /*
*/ legend(lab(1 "to EF") lab(2 "to EP") lab(3 "to UF") lab(4 "to UP") lab(5 "to NLF") rows(1)) xtitle("")
graph export flows_fromEF.eps, as(eps) replace
graph export flows_fromEF.png, as(png) replace

twoway  (line flowEFEP survey, lpattern(solid) lwidth(thick)) /*
*/ (line flowEFUF survey, lpattern(solid) lwidth(thick)) (line flowEFUP survey, lpattern(solid) lwidth(thick)) /*
*/ (line flowEFNN survey, lpattern(solid) lwidth(thick)) ,graphregion(color(white)) yscale(range(0.0 0.15)) ylabel(0.0(0.05) 0.15)  title("Flows_fromEFtoXX", span) /*
*/ legend(lab(1 "to EP") lab(2 "to UF") lab(3 "to UP") lab(4 "to NLF") rows(1)) xtitle("")
graph export flows_fromEFtoOTHERS.eps, as(eps) replace
graph export flows_fromEFtoOTHERS.png, as(png) replace

twoway (line flowEPEF survey, lpattern(solid) lwidth(thick)) (line flowEPEP survey, lpattern(solid) lwidth(thick)) /*
*/ (line flowEPUF survey, lpattern(solid) lwidth(thick)) (line flowEPUP survey, lpattern(solid) lwidth(thick)) /*
*/ (line flowEPNN survey, lpattern(solid) lwidth(thick)) ,graphregion(color(white)) yscale(range(0.0 1.0)) ylabel(0.0(0.2) 1.0)  title("Flows_fromEPtoXX", span) /*
*/ legend(lab(1 "to EF") lab(2 "to EP") lab(3 "to UF") lab(4 "to UP") lab(5 "to NLF") rows(1))  xtitle("")
graph export flows_fromEP.eps, as(eps) replace
graph export flows_fromEP.png, as(png) replace

twoway  (line flowEPEF survey, lpattern(solid) lwidth(thick)) /*
*/ (line flowEPUF survey, lpattern(solid) lwidth(thick)) (line flowEPUP survey, lpattern(solid) lwidth(thick)) /*
*/ (line flowEPNN survey, lpattern(solid) lwidth(thick)) ,graphregion(color(white)) yscale(range(0.0 0.25)) ylabel(0.0(0.05) 0.25)  title("Flows_fromEPtoXX", span) /*
*/ legend(lab(1 "to EF") lab(2 "to UF") lab(3 "to UP") lab(4 "to NLF") rows(1))  xtitle("")
graph export flows_fromEPtoOTHERS.eps, as(eps) replace
graph export flows_fromEPtoOTHERS.png, as(png) replace

twoway (line flowUFEF survey, lpattern(solid) lwidth(thick)) (line flowUFEP survey, lpattern(solid) lwidth(thick)) /*
*/ (line flowUFUF survey, lpattern(solid) lwidth(thick)) (line flowUFUP survey, lpattern(solid) lwidth(thick)) /*
*/ (line flowUFNN survey, lpattern(solid) lwidth(thick)) ,graphregion(color(white)) yscale(range(0.0 1.0)) ylabel(0.0(0.2) 1.0)  title("Flows_fromUFtoXX", span) /*
*/ legend(lab(1 "to EF") lab(2 "to EP") lab(3 "to UF") lab(4 "to UP") lab(5 "to NLF") rows(1)) xtitle("")
graph export flows_fromUF.eps, as(eps) replace
graph export flows_fromUF.png, as(png) replace

twoway  (line flowUFEF survey, lpattern(solid) lwidth(thick)) /*
*/ (line flowUFEP survey, lpattern(solid) lwidth(thick)) (line flowUFUP survey, lpattern(solid) lwidth(thick)) /*
*/ (line flowUFNN survey, lpattern(solid) lwidth(thick)) ,graphregion(color(white)) yscale(range(0.0 0.25)) ylabel(0.0(0.05) 0.25)  title("Flows_fromUFtoXX", span) /*
*/ xtitle("")  legend(lab(1 "to EF") lab(2 "to EP") lab(3 "to UP") lab(4 "to NLF") rows(1))
graph export flows_fromUFtoOTHERS.eps, as(eps) replace
graph export flows_fromUFtoOTHERS.png, as(png) replace

twoway (line flowUPEF survey, lpattern(solid) lwidth(thick)) (line flowUPEP survey, lpattern(solid) lwidth(thick)) /*
*/ (line flowUPUF survey, lpattern(solid) lwidth(thick)) (line flowUPUP survey, lpattern(solid) lwidth(thick)) /*
*/ (line flowUPNN survey, lpattern(solid) lwidth(thick)) ,graphregion(color(white)) yscale(range(0.0 1.0)) ylabel(0.0(0.2) 1.0)  title("Flows_fromUPtoXX", span) /*
*/  xtitle("") legend(lab(1 "to EF") lab(2 "to EP") lab(3 "to UF") lab(4 "to UP") lab(5 "to NLF") rows(1))
graph export flows_fromUP.eps, as(eps) replace
graph export flows_fromUP.png, as(png) replace

twoway  (line flowUPEF survey, lpattern(solid) lwidth(thick)) /*
*/ (line flowUPEP survey, lpattern(solid) lwidth(thick)) (line flowUPUF survey, lpattern(solid) lwidth(thick)) /*
*/ (line flowUPNN survey, lpattern(solid) lwidth(thick)) ,graphregion(color(white)) yscale(range(0.0 0.4)) ylabel(0.0(0.05) 0.4)  title("Flows_fromUPtoXX", span) /*
*/ xtitle("") legend(lab(1 "to EF") lab(2 "to EP") lab(3 "to UF") lab(4 "to NLF") rows(1))
graph export flows_fromUPtoOTHERS.eps, as(eps) replace
graph export flows_fromUPtoOTHERS.png, as(png) replace

twoway (line flowNNEF survey, lpattern(solid) lwidth(thick)) (line flowNNEP survey, lpattern(solid) lwidth(thick)) /*
*/ (line flowNNUF survey, lpattern(solid) lwidth(thick)) (line flowNNUP survey, lpattern(solid) lwidth(thick)) /*
*/ (line flowNNNN survey, lpattern(solid) lwidth(thick)) ,graphregion(color(white)) yscale(range(0.0 1.0)) ylabel(0.0(0.2) 1.0)  title("Flows_fromNLFtoXX", span) /*
*/  xtitle("") legend(lab(1 "to EF") lab(2 "to EP") lab(3 "to UF") lab(4 "to UP") lab(5 "to NLF") rows(1)) 
graph export flows_fromNLF.eps, as(eps) replace
graph export flows_fromNLF.png, as(png) replace

twoway  (line flowNNEF survey, lpattern(solid) lwidth(thick)) /*
*/ (line flowNNEP survey, lpattern(solid) lwidth(thick)) (line flowNNUF survey, lpattern(solid) lwidth(thick)) /*
*/ (line flowNNUP survey, lpattern(solid) lwidth(thick)) ,graphregion(color(white)) yscale(range(0.0 0.2)) ylabel(0.0(0.05) 0.2)  title("Flows_fromNLFtoXX", span) /*
*/ xtitle("") legend(lab(1 "to EF") lab(2 "to EP") lab(3 "to UF") lab(4 "to UP") rows(1))
graph export flows_fromNLFtoOTHERS.eps, as(eps) replace
graph export flows_fromNLFtoOTHERS.png, as(png) replace


twoway  (line frac_ftpt survey, lpattern(solid) lwidth(thick))  (area frac_ftpt survey, color(navy))  (area frac_fp survey, color(eltblue)) /*
*/,graphregion(color(white)) yscale(range(0.0 0.2)) ylabel(0.0(0.05) 0.2)  title("employed workers who move btw FT and PT / total employed workers", span) /*
*/ xtitle("")  legend(lab(1 "Both") lab(2 "PT->FT") lab(3 "FT->PT") rows(1))
graph export rate_ftpt.eps, as(eps) replace
graph export rate_ftpt.png, as(png) replace

twoway  (line frac_ftpt2 survey, lpattern(solid) lwidth(thick))  (area frac_ftpt2 survey, color(navy))  (area frac_fp2 survey, color(eltblue)) /*
*/,graphregion(color(white)) yscale(range(0.0 0.2)) ylabel(0.0(0.05) 0.2)  title("employed workers who move btw FT and PT / Labor Force", span) /*
*/ xtitle("")  legend(lab(1 "Both") lab(2 "PT->FT") lab(3 "FT->PT") rows(1))
graph export rate_ftpt2.eps, as(eps) replace
graph export rate_ftpt2.png, as(png) replace

twoway  (line frac_fp2 survey, lpattern(solid) lwidth(medthick))  (line frac_pf2 survey, lpattern(solid) lwidth(medthick)) /*
*/ (line net_ftpt survey, lpattern(solid) lwidth(medthick)) ,graphregion(color(white)) yscale(range(-0.05 0.1)) ylabel(-0.05(0.05) 0.1)  /*
*/ title("Employed workers who move btw FT and PT / Labor Force", span) /*
*/ xtitle("")  legend(lab(1 "FT->PT") lab(2 "PT->FT") lab(3 "Net FT->PT") rows(1))
graph export rate_ftpt3.eps, as(eps) replace
graph export rate_ftpt3.png, as(png) replace

twoway  (line net_promotion survey, lpattern(solid) lwidth(medthick)),graphregion(color(white)) yscale(range(-0.05 0.1)) ylabel(-0.05(0.05) 0.1)  /*
*/ title("Net Promotion / Part-time", span) /*
*/ xtitle("")  legend(lab(1 "(PT->FT)/Part") rows(1))
graph export rate_promotion.eps, as(eps) replace
graph export rate_promotion.png, as(png) replace


cd `current'\adjustment_usual_PT_until89
use PT_UFT.dta, clear
quietly {
	egen mean_share_UFT=mean(share_UFT), by(month)
	drop year date
	keep if _n <=12
}
keep month mean*
save mean_PT_UFT.dta, replace

use `current'\emp_status_detail.dta, clear
keep date survey frac*
quietly {
	order fracEIP, after(fracEP)
	order fracEVP, after(fracEIP)
	gen str4 year_s=substr(string(date),1,4)
	gen str2 month_s=substr(string(date),5,6)
	gen year= real(year_s)
	gen month = real(month_s)
	drop year_s month_s
	order year, after(date)
	order month, after(year)
	gen ind = 0
	replace ind = 1 if year <=1988
	merge m:1 month using mean_PT_UFT
	drop _merge
	sort date
	gen mean_share_UFT_ind = ind*mean_share_UFT
	gen fracEP_adjust = fracEP*(1-mean_share_UFT_ind)
	gen fracEF_adjust = fracEFT + fracEP*mean_share_UFT_ind
	gen fracEVP_ajust = fracEVP
	gen fracEIP_ajust = fracEP_adjust - fracEVP	
	order fracEF_adjust, after(mean_share_UFT_ind)
	order fracEP_adjust, after(fracEF_adjust)
	order fracEIP_ajust, after(fracEP_adjust)
	order fracEVP_ajust, after(fracEIP_ajust)
	keep date fracEF_adjust fracEP_adjust fracEIP_ajust fracEVP_ajust
	save emp_status_detail_with_adjustment_until88.dta, replace
	export excel using emp_status_detail_adjustment_until88, replace
}


/*
*/
clear
set maxvar 20000
cd `current'
use flows.dta, clear
drop flows* frac*
merge 1:1 date using emp_status, keepus(fracEF fracEP fracUF fracUP fracNN)
sort date
gen all = 1
keep flow* frac* date all
reshape wide flow* frac*, i(all) j(date) 
drop all
local status "EF EP UF UP NN" 
local x=199401
local end=`end_sample'
while `x' <= `end'-1  {
	local x1 = `x' + 1 
	if (`x'-12)/100 == int((`x'-12)/100) {
		local x1 = `x' + 89
	}
	foreach from of local status{
		quietly gen dif_`from' = frac`from'`x1'- frac`from'`x'
		foreach to of local status{
			quietly gen flowfrom`from'to`to' = frac`from'`x'*flow`from'`to'`x1'			
		}
	}
	preserve
		gen from = `x'
		gen to   = `x1'
		keep flowfrom* dif_* fracEF`x' fracEP`x' fracUF`x' fracUP`x' fracNN`x' from to
		order from, first
		order to, after(from)
		foreach st of local status{
			quietly rename frac`st'`x' frac`st'
		}
		if `x'>=199402 {
			append using flowfromto.dta
			sort from
		}
		quietly save flowfromto, replace
	restore
	quietly drop flowfrom* dif_*
	local x = `x1'
}
use flowfromto, clear
foreach from of local status{
	foreach to of local status{
			quietly gen netflowfrom`from'to`to' = flowfrom`from'to`to'-flowfrom`to'to`from'			
	}
}
foreach to of local status{
	egen sum_flow`to' = rowtotal(netflowfromEFto`to' netflowfromEPto`to' netflowfromUFto`to' netflowfromUPto`to' netflowfromNNto`to')
	quietly gen error_`to' = dif_`to'-sum_flow`to'
	order sum_flow`to', after(dif_`to')
	order error_`to', after(sum_flow`to')
}

quietly{
	gen str4 year=substr(string(to),1,4)
	gen str2 month=substr(string(to),5,6)
	gen year_n = real(year)
	gen month_n = real(month)
	gen survey = ym(year_n, month_n)
	order survey, after(from)
	tsset survey, monthly
	drop year month year_n month_n
	save decomposition.dta, replace
	order dif_EF, after(survey)
	order dif_EP, after(sum_flowEF)
	order dif_UF, after(sum_flowEP)
	order dif_UP, after(sum_flowUF)
	order dif_NN, after(sum_flowUP)
	foreach x of varlist netflowfromEFtoEF-netflowfromNNtoNN {
		replace `x' = 0 if(`x' == .)
	}
	foreach to of local status{
		order netflowfromEFto`to', after(dif_`to') 
		order netflowfromEPto`to', after(netflowfromEFto`to')
		order netflowfromUFto`to', after(netflowfromEPto`to') 
		order netflowfromUPto`to', after(netflowfromUFto`to') 
		order netflowfromNNto`to', after(netflowfromUPto`to')
		order error_`to', after(netflowfromNNto`to')
		order sum_flow`to', after(error_`to')
	}
	drop flowfrom*
}
cd `current'\figure_flows
capture mkdir decomposition
cd `current'\figure_flows\decomposition
foreach to of local status{
	graph bar netflowfromEFto`to'  netflowfromEPto`to' netflowfromUFto`to' netflowfromUPto`to' netflowfromNNto`to' error_`to', bar(6, color(gray)) /*
	*/ over(survey) title("decomposition to `to'", span) graphregion(color(white))  legend(lab(1 "from EF") lab(2 "from EP") lab(3 "from UF")  lab(4 "from UP") lab(5 "from NN") lab(6 "error")) bargap(-50) stack
	graph export decomposition_to`to'.eps, as(eps) replace
	graph export decomposition_to`to'.png, as(png) replace
}



if `IPT_VPT'==1	{
	*set maxvar 20000
	cd `current'
	use flows_detail.dta, clear
	capture drop flows* frac*
	merge 1:1 date using emp_status_detail, keepus(fracEFT fracEIP fracEVP fracUFT fracUPT fracNNN)
	sort date
	gen all = 1
	keep flow* frac* date all
	reshape wide flow* frac*, i(all) j(date) 
	drop all
	local status "EFT EIP EVP UFT UPT NNN" 	
	local x=199401
	local end=`end_sample'
	
	while `x' <= `end'-1  {
	local x1 = `x' + 1 
	if (`x'-12)/100 == int((`x'-12)/100) {
		local x1 = `x' + 89
	}
	foreach from of local status{
		quietly gen dif_`from' = frac`from'`x1'- frac`from'`x'
		foreach to of local status{
			quietly gen flowfrom`from'to`to' = frac`from'`x'*flow`from'`to'`x1'			
		}
	}
	preserve
		gen from = `x'
		gen to   = `x1'
		keep flowfrom* dif_* fracEFT`x' fracEIP`x' fracEVP`x' fracUFT`x' fracUPT`x' fracNNN`x' from to
		order from, first
		order to, after(from)
		foreach st of local status{
			quietly rename frac`st'`x' frac`st'
		}
		if `x'>=199402 {
			append using flowfromto_detail.dta
			sort from
		}
		quietly save flowfromto_detail, replace
	restore
	quietly drop flowfrom* dif_*
	local x = `x1'

	use flowfromto_detail, clear
	foreach from of local status{
		foreach to of local status{
				quietly gen netflowfrom`from'to`to' = flowfrom`from'to`to'-flowfrom`to'to`from'			
		}
	}
	foreach to of local status{
		egen sum_flow`to' = rowtotal(netflowfromEFTto`to' netflowfromEIPto`to' netflowfromEVPto`to' netflowfromUFTto`to' netflowfromUPTto`to' netflowfromNNNto`to')
		quietly gen error_`to' = dif_`to'-sum_flow`to'
		order sum_flow`to', after(dif_`to')
		order error_`to', after(sum_flow`to')
	}

	quietly{
		gen str4 year=substr(string(to),1,4)
		gen str2 month=substr(string(to),5,6)
		gen year_n = real(year)
		gen month_n = real(month)
		gen survey = ym(year_n, month_n)
		order survey, after(from)
		tsset survey, monthly
		drop year month year_n month_n
		save decomposition.dta, replace
		order dif_EF, after(survey)
		order dif_EIP, after(sum_flowEFT)
		order dif_EVP, after(sum_flowEIP)
		order dif_UFT, after(sum_flowEVP)
		order dif_UPT, after(sum_flowUFT)
		order dif_NNN, after(sum_flowUPT)
		foreach x of varlist netflowfromEFTtoEFT-netflowfromNNNtoNNN {
			replace `x' = 0 if(`x' == .)
		}
		foreach to of local status{
			order netflowfromEFTto`to', after(dif_`to') 
			order netflowfromEIPto`to', after(netflowfromEFTto`to')
			order netflowfromEVPto`to', after(netflowfromEIFTto`to')
			order netflowfromUFTto`to', after(netflowfromEVPto`to') 
			order netflowfromUPTto`to', after(netflowfromUFTto`to') 
			order netflowfromNNNto`to', after(netflowfromUPTto`to')
			order error_`to', after(netflowfromNNNto`to')
			order sum_flow`to', after(error_`to')
		}
		drop flowfrom*
	}
}
cd `current'\figure_flows
capture mkdir decomposition_detail
cd `current'\figure_flows\decomposition_detail
foreach to of local status{
	graph bar netflowfromEFTto`to' netflowfromEIPto`to' netflowfromEVPto`to' netflowfromUFTto`to' netflowfromUPTto`to' netflowfromNNNto`to' error_`to', bar(6, color(gray)) /*
	*/ over(survey) title("decomposition to `to'", span) graphregion(color(white))  legend(lab(1 "from EFT") lab(2 "from EIP") lab(3 "from EVP") lab(4 "from UFT")  lab(5 "from UPT") lab(6 "from NN") lab(7 "error")) bargap(-50) stack
	graph export decomposition_to`to'.eps, as(eps) replace
	graph export decomposition_to`to'.png, as(png) replace
}


