% This is the code to decompose the IRE of employment stock into
% contribution of different flows

% Kazuhiro Teramoto

clc
clear all
close all

close all

set(0,'defaultAxesFontSize',12);
set(0,'defaultAxesFontName','Times');
set(0,'defaultTextFontSize',12);
set(0,'defaultTextFontName','Times');

result = dir('*_results.mat');
load(result.name);

plot_pp = 1;
pp_figure_mode = 0;
birf = 1;
birf2 = 1;

filename  = M_.dname;
datafile  = options_.datafile;
paranames = M_.param_names;
endonames = M_.endo_names;
obs_names = options_.varobs;
exo_names = M_.exo_names;
exo_name_long = M_.exo_names_long;
paravalue = M_.params;
sig_value = diag(M_.Sigma_e);
paravalue_str = num2str(paravalue,16);
[nendo nchar_endo]= size(M_.endo_names);
[n_exo nchar_exo]= size(exo_names);
[nobs nchar_obs]= size(obs_names);
if (size(M_.param_names,1) ~=  size(paravalue_str,1))
    error('parameter size is strange')
end
% set parameter values
for i = 1:size(M_.param_names,1)
    eval(cell2mat(strcat('index_',deblank(M_.param_names(i,:)),'=',num2str(i),';')));
    eval(cell2mat(strcat(deblank(M_.param_names(i,:)),'=',paravalue_str(i,:),';')));
end
% find estimated parameters among parameters above
index_estparas = estim_params_.param_vals(:,1);
est_para_name_cell = cellstr(M_.param_names(index_estparas,:));
est_para_name_cell_tex = cellstr(M_.param_names_tex(index_estparas,:));

% set indexes for endogenous varibles
for i = 1:M_.endo_nbr
    eval(cell2mat(strcat(M_.endo_names(i,:),'=',num2str(i),';')));
end
if isempty(M_.aux_vars) == 0
    aux_val = M_.endo_names([M_.aux_vars.orig_index],:);
end
% set indexes for exogenous varibles and stdv. of innovations
for i = 1:M_.exo_nbr
    eval(cell2mat(strcat(deblank(exo_names(i,:)),'=',num2str(i),';')));
    eval(cell2mat(strcat('sig_',deblank(exo_names(i,:)),'=',num2str(M_.Sigma_e(i,i)^(1/2)),';')));
end
cellexoval = cellstr(exo_names);
cellexoval_tex = cellstr(M_.exo_names_tex);



nirf = options_.irf;                % the maximum period of 
cellexoval = cellstr(exo_names);
cellendoval = cellstr(endonames);
variables = [n_ful  n_pat flow_EU_ful flow_EE_ful flow_EU_pat flow_EE_pat];
val_s = cellstr(char(M_.endo_names_long(variables,:)));
variables_name = cellendoval(variables);
shocks_name = cellexoval;
irf_decomp = zeros(length(variables),nirf,n_exo);
for i = 1:size(irf_decomp,1)
    vname = variables_name(i);
    for j = 1:size(irf_decomp,2)
        for k = 1:size(irf_decomp,3)
            sname = shocks_name(k);
            irf_decomp(i,j,k) = eval(char(strcat('oo_.irfs.',vname,'_',sname,'(j)' ))); %n_ful_e_z(j);
        end
    end
end

flow_EU_ful_ss=xss_ful-(1-rhoss_ful)*(1-lam_fp); 
flow_EE_ful_ss=varphi_ss*rhoss_pat*nss_pat/nss_ful- lam_fp*(1-rhoss_ful); 
flow_EU_pat_ss=xss_pat-(1-rhoss_pat); 
flow_EE_pat_ss=-varphi_ss*rhoss_pat+lam_fp*(1-rhoss_ful)*nss_ful/nss_pat;

irf_decomp_ful = zeros(3,nirf,n_exo);
irf_decomp_pat = zeros(3,nirf,n_exo);
for k = 1:size(irf_decomp,3)
    disp('irfs decomposition: full-time')
    flow_EU_ful_sum = (flow_EU_ful_ss*squeeze(irf_decomp(3,1:nirf,k)))*triu(ones(nirf,nirf));
    flow_EE_ful_sum = (flow_EE_ful_ss*squeeze(irf_decomp(4,1:nirf,k)))*triu(ones(nirf,nirf));
    check = squeeze(irf_decomp(1,:,k)) - (flow_EU_ful_sum + flow_EE_ful_sum);
    %dif = check./squeeze(irf_decomp(1,:,k));    
    dif =  check;
    %if max(abs(check_ful))/max(abs(squeeze(irf_decomp(1,:,k)))) > 1e-4
    if max(abs(dif)) > 1e-4
        disp([max(dif),min(dif),k]);
    end
    irf_decomp_ful(:,:,k) = [irf_decomp(1,:,k); flow_EU_ful_sum; flow_EE_ful_sum];
    disp('irfs decomposition: part-time')
    flow_EU_pat_sum = (flow_EU_pat_ss*squeeze(irf_decomp(5,1:nirf,k))*triu(ones(nirf,nirf)));
    flow_EE_pat_sum = (flow_EE_pat_ss*squeeze(irf_decomp(6,1:nirf,k))*triu(ones(nirf,nirf)));
    check = squeeze(irf_decomp(2,:,k)) - (flow_EU_pat_sum + flow_EE_pat_sum);
    %dif = check./squeeze(irf_decomp(2,:,k));
    dif =  check;
    if max(abs(dif)) > 1e-4
        disp([max(dif),min(dif),k]);
    end
    irf_decomp_pat(:,:,k) = [irf_decomp(2,:,k); flow_EU_pat_sum; flow_EE_pat_sum];
end

% making table
fid = fopen('IRF_decomposition_table.tex','w');
fprintf(fid,'\\begin{table}[t!]\n');
fprintf(fid,'\\caption{ Decomposed impulse responses: A positive technology shock} \n');
fprintf(fid,'\\centering \n \\small \n');
%fprintf(fid,'\\scalebox{.9}[.9]{ \n');
fprintf(fid,'\\resizebox{\\textwidth}{!}{ \n');
fprintf(fid,'{\\tabcolsep = 1.0mm \n');
fprintf(fid,'\\begin{tabular}{clccccccccccccccccc}\n');
fprintf(fid,'\\toprule \n');
fprintf(fid,' &&\\multicolumn{7}{c}{Full-time employment rate ($\\ell = F$)}	&&	\\multicolumn{7}{c}{Part-time employment rate ($\\ell = P$)} \\\\  \\cmidrule(r){3-9}\\cmidrule(r){11-17}\n');
fprintf(fid,' Horizons      && on impact && $1$ quarters && $2$ quarters && one year	  &&on impact && $1$ quarters && $2$ quarters && one year \\\\ \\cmidrule(r){3-9}\\cmidrule(r){11-17} \n');
fprintf(fid,' $\\tilde{n}^{\\ell}_t$ && %8.2f &&  %8.2f && %8.2f && %8.2f && %8.2f && %8.2f && %8.2f  && %8.2f  \\\\  \\cmidrule(r){3-9}\\cmidrule(r){11-17} \n',  irf_decomp_ful(1,1,1), irf_decomp_ful(1,2,1), irf_decomp_ful(1,3,1),  irf_decomp_ful(1,5,1), irf_decomp_pat(1,1,1), irf_decomp_pat(1,2,1), irf_decomp_pat(1,3,1),  irf_decomp_pat(1,5,1));
fprintf(fid,' From $EF$  && -- && -- && -- && -- && %8.2f && %8.2f && %8.2f && %8.2f  \\\\ \n',  irf_decomp_pat(3,1,1), irf_decomp_pat(3,2,1), irf_decomp_pat(3,3,1),  irf_decomp_pat(3,5,1));
fprintf(fid,' From $EP$  && %8.2f && %8.2f && %8.2f && %8.2f && -- && -- && -- && --  \\\\ \n',  irf_decomp_ful(3,1,1), irf_decomp_ful(3,2,1), irf_decomp_ful(3,3,1),  irf_decomp_ful(3,5,1));
fprintf(fid,' From $U$  && %8.2f && %8.2f && %8.2f && %8.2f && %8.2f && %8.2f && %8.2f  && %8.2f \\\\ \n',  irf_decomp_ful(2,1,1), irf_decomp_ful(2,2,1), irf_decomp_ful(2,3,1),  irf_decomp_ful(2,5,1),irf_decomp_pat(2,1,1), irf_decomp_pat(2,2,1), irf_decomp_pat(2,3,1),  irf_decomp_pat(2,5,1));
fprintf(fid, '\\bottomrule  \n');
fprintf(fid, '\\end{tabular} \n');
fprintf(fid, '}} \n');
fprintf(fid, '\\raggedright \n \\vspace{2mm}\n');
fprintf(fid, '\n');
fprintf(fid, '  \\begin{minilinespace}\n  \\begin{footnotesize}\n'); 
fprintf(fid, '  \\textit{Note}:   \n'); 
fprintf(fid, '  \\end{footnotesize} \n  \\end{minilinespace} \\label{table_IRF_tec} \n\\end{table} \n');
%fprintf(fid,'\\cline{2-6}\n');



fprintf(fid, '\n');
fprintf(fid,'\\begin{table}[t!]\n');
fprintf(fid,'\\caption{ Decomposed impulse responses: A positive investment-specific technology shock} \n');
fprintf(fid,'\\centering \n \\small \n');
fprintf(fid,'\\resizebox{\\textwidth}{!}{ \n');
fprintf(fid,'{\\tabcolsep = 1.0mm \n');
fprintf(fid,'\\begin{tabular}{clccccccccccccccccc}\n');
fprintf(fid,'\\toprule \n');
fprintf(fid,' &&\\multicolumn{7}{c}{Full-time employment rate ($\\ell = F$)}	&&	\\multicolumn{7}{c}{Part-time employment rate ($\\ell = P$)} \\\\  \\cmidrule(r){3-9}\\cmidrule(r){11-17}\n');
fprintf(fid,' Horizons      && on impact && $1$ quarters && $2$ quarters && one year	  &&on impact && $1$ quarters && $2$ quarters && one year \\\\ \\cmidrule(r){3-9}\\cmidrule(r){11-17} \n');
fprintf(fid,' $\\tilde{n}^{\\ell}_t$ && %8.2f &&  %8.2f && %8.2f && %8.2f && %8.2f && %8.2f && %8.2f  && %8.2f  \\\\  \\cmidrule(r){3-9}\\cmidrule(r){11-17} \n',  irf_decomp_ful(1,1,3), irf_decomp_ful(1,2,3), irf_decomp_ful(1,3,3),  irf_decomp_ful(1,5,3), irf_decomp_pat(1,1,3), irf_decomp_pat(1,2,3), irf_decomp_pat(1,3,3),  irf_decomp_pat(1,5,3));
fprintf(fid,' From $EF$  && -- && -- && -- && -- && %8.2f && %8.2f && %8.2f && %8.2f  \\\\ \n',  irf_decomp_pat(3,1,3), irf_decomp_pat(3,2,3), irf_decomp_pat(3,3,3),  irf_decomp_pat(3,5,3));
fprintf(fid,' From $EP$  && %8.2f && %8.2f && %8.2f && %8.2f && -- && -- && -- && --  \\\\ \n',  irf_decomp_ful(3,1,3), irf_decomp_ful(3,2,3), irf_decomp_ful(3,3,3),  irf_decomp_ful(3,5,3));
fprintf(fid,' From $U$  && %8.2f && %8.2f && %8.2f && %8.2f && %8.2f && %8.2f && %8.2f  && %8.2f \\\\ \n',  irf_decomp_ful(2,1,3), irf_decomp_ful(2,2,3), irf_decomp_ful(2,3,3),  irf_decomp_ful(2,5,3),irf_decomp_pat(2,1,3), irf_decomp_pat(2,2,3), irf_decomp_pat(2,3,3),  irf_decomp_pat(2,5,3));
fprintf(fid, '\\bottomrule  \n');
fprintf(fid, '\\end{tabular} \n');
fprintf(fid, '}} \n');
fprintf(fid, '\\raggedright \n \\vspace{2mm}\n');
fprintf(fid, '\n');
fprintf(fid, '  \\begin{minilinespace}\n  \\begin{footnotesize}\n'); 
fprintf(fid, '  \\textit{Note}:   \n'); 
fprintf(fid, '  \\end{footnotesize} \n  \\end{minilinespace} \\label{table_IRF_IST} \n\\end{table} \n');
%fprintf(fid,'\\cline{2-6}\n');
fopen(fid);


fprintf(fid, '\n');
fprintf(fid,'\\begin{table}[t!]\n');
fprintf(fid,'\\caption{ Decomposed impulse responses: A positive intertemporal preference  shock} \n');
fprintf(fid,'\\centering \n \\small \n');
fprintf(fid,'\\resizebox{\\textwidth}{!}{ \n');
fprintf(fid,'{\\tabcolsep = 1.0mm \n');
fprintf(fid,'\\begin{tabular}{clccccccccccccccccc}\n');
fprintf(fid,'\\toprule \n');
fprintf(fid,' &&\\multicolumn{7}{c}{Full-time employment rate ($\\ell = F$)}	&&	\\multicolumn{7}{c}{Part-time employment rate ($\\ell = P$)} \\\\  \\cmidrule(r){3-9}\\cmidrule(r){11-17}\n');
fprintf(fid,' Horizons      && on impact && $1$ quarters && $2$ quarters && one year	  &&on impact && $1$ quarters && $2$ quarters && one year \\\\ \\cmidrule(r){3-9}\\cmidrule(r){11-17} \n');
fprintf(fid,' $\\tilde{n}^{\\ell}_t$ && %8.2f &&  %8.2f && %8.2f && %8.2f && %8.2f && %8.2f && %8.2f  && %8.2f  \\\\  \\cmidrule(r){3-9}\\cmidrule(r){11-17} \n',  irf_decomp_ful(1,1,2), irf_decomp_ful(1,2,2), irf_decomp_ful(1,3,2),  irf_decomp_ful(1,5,2), irf_decomp_pat(1,1,2), irf_decomp_pat(1,2,2), irf_decomp_pat(1,3,2),  irf_decomp_pat(1,5,2));
fprintf(fid,' From $EF$  && -- && -- && -- && -- && %8.2f && %8.2f && %8.2f && %8.2f  \\\\ \n',  irf_decomp_pat(3,1,2), irf_decomp_pat(3,2,2), irf_decomp_pat(3,3,2),  irf_decomp_pat(3,5,2));
fprintf(fid,' From $EP$  && %8.2f && %8.2f && %8.2f && %8.2f && -- && -- && -- && --  \\\\ \n',  irf_decomp_ful(3,1,2), irf_decomp_ful(3,2,2), irf_decomp_ful(3,3,2),  irf_decomp_ful(3,5,2));
fprintf(fid,' From $U$  && %8.2f && %8.2f && %8.2f && %8.2f && %8.2f && %8.2f && %8.2f  && %8.2f \\\\ \n',  irf_decomp_ful(2,1,2), irf_decomp_ful(2,2,2), irf_decomp_ful(2,3,2),  irf_decomp_ful(2,5,2),irf_decomp_pat(2,1,2), irf_decomp_pat(2,2,2), irf_decomp_pat(2,3,2),  irf_decomp_pat(2,5,2));
fprintf(fid, '\\bottomrule  \n');
fprintf(fid, '\\end{tabular} \n');
fprintf(fid, '}} \n');
fprintf(fid, '\\raggedright \n \\vspace{2mm}\n');
fprintf(fid, '\n');
fprintf(fid, '  \\begin{minilinespace}\n  \\begin{footnotesize}\n'); 
fprintf(fid, '  \\textit{Note}:   \n'); 
fprintf(fid, '  \\end{footnotesize} \n  \\end{minilinespace} \\label{table_IRF_IP} \n\\end{table} \n');
%fprintf(fid,'\\cline{2-6}\n');
fopen(fid);

fprintf(fid, '\n');
fprintf(fid,'\\begin{table}[t!]\n');
fprintf(fid,'\\caption{ Decomposed impulse responses: A positive price markup  shock} \n');
fprintf(fid,'\\centering \n \\small \n');
fprintf(fid,'\\resizebox{\\textwidth}{!}{ \n');
fprintf(fid,'{\\tabcolsep = 1.0mm \n');
fprintf(fid,'\\begin{tabular}{clccccccccccccccccc}\n');
fprintf(fid,'\\toprule \n');
fprintf(fid,' &&\\multicolumn{7}{c}{Full-time employment ($\\ell = F$)}	&&	\\multicolumn{7}{c}{Part-time employment ($\\ell = P$)} \\\\  \\cmidrule(r){3-9}\\cmidrule(r){11-17}\n');
fprintf(fid,' Horizons      && on impact && $2$ quarters && $4$ quarters && $8$ quarters	  &&on impact && $1$ quarter && $4$ quarters && $8$ quarters \\\\ \\cmidrule(r){3-9}\\cmidrule(r){11-17} \n');
fprintf(fid,' $\\tilde{n}^{\\ell}_t$ && %8.2f &&  %8.2f && %8.2f && %8.2f && %8.2f && %8.2f && %8.2f  && %8.2f  \\\\  \\cmidrule(r){3-9}\\cmidrule(r){11-17} \n',  irf_decomp_ful(1,1,4), irf_decomp_ful(1,2,4), irf_decomp_ful(1,3,4),  irf_decomp_ful(1,5,4), irf_decomp_pat(1,1,4), irf_decomp_pat(1,2,4), irf_decomp_pat(1,3,4),  irf_decomp_pat(1,5,4));
fprintf(fid,' From $EF$  && -- && -- && -- && -- && %8.2f && %8.2f && %8.2f && %8.2f  \\\\ \n',  irf_decomp_pat(3,1,4), irf_decomp_pat(3,2,4), irf_decomp_pat(3,3,4),  irf_decomp_pat(3,5,4));
fprintf(fid,' From $EP$  && %8.2f && %8.2f && %8.2f && %8.2f && -- && -- && -- && --  \\\\ \n',  irf_decomp_ful(3,1,4), irf_decomp_ful(3,2,4), irf_decomp_ful(3,3,4),  irf_decomp_ful(3,5,4));
fprintf(fid,' From $U$  && %8.2f && %8.2f && %8.2f && %8.2f && %8.2f && %8.2f && %8.2f  && %8.2f \\\\ \n',  irf_decomp_ful(2,1,4), irf_decomp_ful(2,2,4), irf_decomp_ful(2,3,4),  irf_decomp_ful(2,5,4),irf_decomp_pat(2,1,4), irf_decomp_pat(2,2,4), irf_decomp_pat(2,3,4),  irf_decomp_pat(2,5,4));
fprintf(fid, '\\bottomrule  \n');
fprintf(fid, '\\end{tabular} \n');
fprintf(fid, '}} \n');
fprintf(fid, '\\raggedright \n \\vspace{2mm}\n');
fprintf(fid, '\n');
fprintf(fid, '  \\begin{minilinespace}\n  \\begin{footnotesize}\n'); 
fprintf(fid, '  \\textit{Note}:   \n'); 
fprintf(fid, '  \\end{footnotesize} \n  \\end{minilinespace} \\label{table_IRF_PM} \n\\end{table} \n');
%fprintf(fid,'\\cline{2-6}\n');
fopen(fid);

fprintf(fid, '\n');
fprintf(fid,'\\begin{table}[t!]\n');
fprintf(fid,'\\caption{ Decomposed impulse responses: A positive government spending shock} \n');
fprintf(fid,'\\centering \n \\small \n');
fprintf(fid,'\\resizebox{\\textwidth}{!}{ \n');
fprintf(fid,'{\\tabcolsep = 1.0mm \n');
fprintf(fid,'\\begin{tabular}{clccccccccccccccccc}\n');
fprintf(fid,'\\toprule \n');
fprintf(fid,' &&\\multicolumn{7}{c}{Full-time employment ($\\ell = F$)}	&&	\\multicolumn{7}{c}{Part-time employment ($\\ell = P$)} \\\\  \\cmidrule(r){3-9}\\cmidrule(r){11-17}\n');
fprintf(fid,' Horizons      && on impact && $2$ quarters && $4$ quarters && $8$ quarters	  &&on impact && $1$ quarter && $4$ quarters && $8$ quarters \\\\ \\cmidrule(r){3-9}\\cmidrule(r){11-17} \n');
fprintf(fid,' $\\tilde{n}^{\\ell}_t$ && %8.2f &&  %8.2f && %8.2f && %8.2f && %8.2f && %8.2f && %8.2f  && %8.2f  \\\\  \\cmidrule(r){3-9}\\cmidrule(r){11-17} \n',  irf_decomp_ful(1,1,5), irf_decomp_ful(1,2,5), irf_decomp_ful(1,3,5),  irf_decomp_ful(1,5,5), irf_decomp_pat(1,1,5), irf_decomp_pat(1,2,5), irf_decomp_pat(1,3,5),  irf_decomp_pat(1,5,5));
fprintf(fid,' From $EF$  && -- && -- && -- && -- && %8.2f && %8.2f && %8.2f && %8.2f  \\\\ \n',  irf_decomp_pat(3,1,5), irf_decomp_pat(3,2,5), irf_decomp_pat(3,3,5),  irf_decomp_pat(3,5,5));
fprintf(fid,' From $EP$  && %8.2f && %8.2f && %8.2f && %8.2f && -- && -- && -- && --  \\\\ \n',  irf_decomp_ful(3,1,5), irf_decomp_ful(3,2,5), irf_decomp_ful(3,3,5),  irf_decomp_ful(3,5,5));
fprintf(fid,' From $U$  && %8.2f && %8.2f && %8.2f && %8.2f && %8.2f && %8.2f && %8.2f  && %8.2f \\\\ \n',  irf_decomp_ful(2,1,5), irf_decomp_ful(2,2,5), irf_decomp_ful(2,3,5),  irf_decomp_ful(2,5,5),irf_decomp_pat(2,1,5), irf_decomp_pat(2,2,5), irf_decomp_pat(2,3,5),  irf_decomp_pat(2,5,5));
fprintf(fid, '\\bottomrule  \n');
fprintf(fid, '\\end{tabular} \n');
fprintf(fid, '}} \n');
fprintf(fid, '\\raggedright \n \\vspace{2mm}\n');
fprintf(fid, '\n');
fprintf(fid, '  \\begin{minilinespace}\n  \\begin{footnotesize}\n'); 
fprintf(fid, '  \\textit{Note}:   \n'); 
fprintf(fid, '  \\end{footnotesize} \n  \\end{minilinespace} \\label{table_IRF_G} \n\\end{table} \n');
%fprintf(fid,'\\cline{2-6}\n');
fopen(fid);

fprintf(fid, '\n');
fprintf(fid,'\\begin{table}[h]\n');
fprintf(fid,'\\caption{ Decomposed impulse responses: A contractionary monetary policy shock} \n');
fprintf(fid,'\\centering \n \\small \n');
fprintf(fid,'\\resizebox{\\textwidth}{!}{ \n');
fprintf(fid,'{\\tabcolsep = 1.0mm \n');
fprintf(fid,'\\begin{tabular}{clccccccccccccccccc}\n');
fprintf(fid,'\\toprule \n');
fprintf(fid,' &&\\multicolumn{7}{c}{Full-time employment rate ($\\ell = F$)}	&&	\\multicolumn{7}{c}{Part-time employment rate ($\\ell = P$)} \\\\  \\cmidrule(r){3-9}\\cmidrule(r){11-17}\n');
fprintf(fid,' Horizons      && on impact && $1$ quarters && $2$ quarters && one year	  &&on impact && $1$ quarters && $2$ quarters && one year \\\\ \\cmidrule(r){3-9}\\cmidrule(r){11-17} \n');
fprintf(fid,' $\\tilde{n}^{\\ell}_t$ && %8.2f &&  %8.2f && %8.2f && %8.2f && %8.2f && %8.2f && %8.2f  && %8.2f  \\\\  \\cmidrule(r){3-9}\\cmidrule(r){11-17} \n',  irf_decomp_ful(1,1,6), irf_decomp_ful(1,2,6), irf_decomp_ful(1,3,6),  irf_decomp_ful(1,5,6), irf_decomp_pat(1,1,6), irf_decomp_pat(1,2,6), irf_decomp_pat(1,3,6),  irf_decomp_pat(1,5,6));
fprintf(fid,' From $EF$  && -- && -- && -- && -- && %8.2f && %8.2f && %8.2f && %8.2f  \\\\ \n',  irf_decomp_pat(3,1,6), irf_decomp_pat(3,2,6), irf_decomp_pat(3,3,6),  irf_decomp_pat(3,5,6));
fprintf(fid,' From $EP$  && %8.2f && %8.2f && %8.2f && %8.2f && -- && -- && -- && --  \\\\ \n',  irf_decomp_ful(3,1,6), irf_decomp_ful(3,2,6), irf_decomp_ful(3,3,6),  irf_decomp_ful(3,5,6));
fprintf(fid,' From $U$  && %8.2f && %8.2f && %8.2f && %8.2f && %8.2f && %8.2f && %8.2f  && %8.2f \\\\ \n',  irf_decomp_ful(2,1,6), irf_decomp_ful(2,2,6), irf_decomp_ful(2,3,6),  irf_decomp_ful(2,5,6),irf_decomp_pat(2,1,6), irf_decomp_pat(2,2,6), irf_decomp_pat(2,3,6),  irf_decomp_pat(2,5,6));
fprintf(fid, '\\bottomrule  \n');
fprintf(fid, '\\end{tabular} \n');
fprintf(fid, '}} \n');
fprintf(fid, '\\raggedright \n \\vspace{2mm}\n');
fprintf(fid, '\n');
fprintf(fid, '  \\begin{minilinespace}\n  \\begin{footnotesize}\n'); 
fprintf(fid, '  \\textit{Note}:   \n'); 
fprintf(fid, '  \\end{footnotesize} \n  \\end{minilinespace} \\label{table_IRF_MP} \n\\end{table} \n');
%fprintf(fid,'\\cline{2-6}\n');
fopen(fid);



set(0,'defaultAxesFontSize',14);
set(0,'defaultAxesFontName','Times');
set(0,'defaultTextFontSize',14);
set(0,'defaultTextFontName','Times');

DirectoryName = [ M_.fname '/decomposed_irfs_full_time' ];
if ~isdir(DirectoryName)
    mkdir('.',DirectoryName);
end
temp = strcat('./',DirectoryName);
oldFolder =  cd(temp);
labels = {'Net UE flow', 'Net EE flow'};
color = [[0.05 0.05 0.05]; [0.75 0.75 0.75]];
for ss = 1:size(irf_decomp,3) % shock
    z1 = squeeze(irf_decomp_ful(2:3,:,ss));
    ix = z1 > 0;
    ymax = max(sum(z1.*ix));
    ix = z1 < 0;
    ymin = min(sum(z1.*ix));
    y_grid = zeros(2,nirf);
    figure
    ax=axes('Position',[0.1300 0.1300 0.7750 0.8150]);
    %plot(ax,x(1:end-1),z1(end,:),'k-','LineWidth',2.3)
    axis(ax,[1 nirf ymin ymax]);
    %line1=plot(ax,1:nirf, squeeze(irf_decomp_ful(1,:,ss)), 'Color',[0.1,0.1,0.1],'LineWidth',2.5);
    hold on;
    for i=1:nirf
        i_1 = i-1;
        yp = 0;
        ym = 0;
        for k = 1:2
            zz = z1(k,i);
            if zz > 0
                ps= fill([i i i+1 i+1],[yp yp+zz yp+zz yp],color(k,:));
                %ps = patch([i i i+1 i+1],[yp yp+zz yp+zz yp],colorstr,'FaceAlpha',0.7,'EdgeColor','none');
                uistack(ps,'bottom')
                set(ps,'facealpha',.6)
                yp = yp+zz;
            else
                ps2 = fill([i i i+1 i+1],[ym ym+zz ym+zz ym],color(k,:));
                uistack(ps2,'bottom')
                set(ps2,'facealpha',.6)
                ym = ym+zz;
            end
            hold on;
        end
        y_grid(:,i) = [yp ym];
    end
    y_gridmm = [max(y_grid(1,:)) min(y_grid(2,:))];
    line1=plot(ax,1:nirf, squeeze(irf_decomp_ful(1,:,ss)), 'blue','LineWidth',2.5);
    axis tight
    %title(deblank(char(shock_name_temp(ss,:))));
    
    axes('Position',[.4 .021 .2 0.021]);
    axis([0 1 0 1]);
    axis off;
    hold on;
    y1 = 0;
    y2 = 1.0;
    width = 0.11;
    width2 = width + 0.04;
    space = 0.9;
    height = 1/2;
    %labels = char(shock_name,'Init. values');  
    for i=1:2
        ps=fill([0+space*(i-1)  0+space*(i-1) width+space*(i-1) width+space*(i-1)],[y1 y1+y2 y1+y2 y1],color(i,:));
        set(ps,'facealpha',.6)
        hold on
        text(width2+space*(i-1),(y1+y2)/2,labels(i),'Interpreter','none');
        %y1 = y1 + height;
    end
    h = findobj(gca,'Type','patch');
    set(h,'EdgeColor','none');
    set(gca, 'Layer', 'top')
    print(['Full-time_Decomposed_irfs_',sprintf('%s',char(cellexoval(ss))) '.eps'],'-depsc2');
end
cd(oldFolder)

DirectoryName = [ M_.fname '/decomposed_irfs_part_time' ];
if ~isdir(DirectoryName)
    mkdir('.',DirectoryName);
end
temp = strcat('./',DirectoryName);
oldFolder =  cd(temp);
labels = {'Net UE flow', 'Net EE flow'};
color = [[0.05 0.05 0.05]; [0.75 0.75 0.75]];
for ss = 1:size(irf_decomp,3) % shock
    z1 = squeeze(irf_decomp_pat(2:3,:,ss));
    ix = z1 > 0;
    ymax = max(sum(z1.*ix));
    ix = z1 < 0;
    ymin = min(sum(z1.*ix));
    y_grid = zeros(2,nirf);
    figure
    ax=axes('Position',[0.1300 0.1300 0.7750 0.8150]);
    %plot(ax,x(1:end-1),z1(end,:),'k-','LineWidth',2.3)
    axis(ax,[1 nirf ymin ymax]);
    %line1=plot(ax,1:nirf, squeeze(irf_decomp_ful(1,:,ss)), 'Color',[0.1,0.1,0.1],'LineWidth',2.5);
    hold on;
    for i=1:nirf
        i_1 = i-1;
        yp = 0;
        ym = 0;
        for k = 1:2
            zz = z1(k,i);
            if zz > 0
                ps= fill([i i i+1 i+1],[yp yp+zz yp+zz yp],color(k,:),'facealpha',.6);
                %ps = patch([i i i+1 i+1],[yp yp+zz yp+zz yp],colorstr,'FaceAlpha',0.7,'EdgeColor','none');
                uistack(ps,'bottom')
                yp = yp+zz;
            else
                ps2 = fill([i i i+1 i+1],[ym ym+zz ym+zz ym],color(k,:),'facealpha',.6);
                uistack(ps2,'bottom')
                ym = ym+zz;
            end
            hold on;
        end
        y_grid(:,i) = [yp ym];
    end
    y_gridmm = [max(y_grid(1,:)) min(y_grid(2,:))];
    line1=plot(ax,1:nirf, squeeze(irf_decomp_pat(1,:,ss)), 'blue','LineWidth',2.5);
    axis tight
    %title(deblank(char(shock_name_temp(ss,:))));
    
    axes('Position',[.4 .021 .2 0.021]);
    axis([0 1 0 1]);
    axis off;
    hold on;
    y1 = 0;
    y2 = 1.0;
    width = 0.11;
    width2 = width + 0.04;
    space = 0.9;
    height = 1/2;
    %labels = char(shock_name,'Init. values');  
    for i=1:2
        ps=fill([0+space*(i-1)  0+space*(i-1) width+space*(i-1) width+space*(i-1)],[y1 y1+y2 y1+y2 y1],color(i,:),'facealpha',.6);
        hold on
        text(width2+space*(i-1),(y1+y2)/2,labels(i),'Interpreter','none');
        %y1 = y1 + height;
    end
    h = findobj(gca,'Type','patch');
    set(h,'EdgeColor','none');
    set(gca, 'Layer', 'top')
    print(['Part-time_Decomposed_irfs_',sprintf('%s',char(cellexoval(ss))) '.eps'],'-depsc2');
end
cd(oldFolder)


set(0,'defaultAxesFontSize',11);
set(0,'defaultAxesFontName','Times');
set(0,'defaultTextFontSize',11);
set(0,'defaultTextFontName','Times');
DirectoryName = [ M_.fname '/decomposed_irfs' ];
if ~isdir(DirectoryName)
    mkdir('.',DirectoryName);
end
temp = strcat('./',DirectoryName);
oldFolder =  cd(temp);
labels = {'Net UE flow', 'Net EE flow'};
color = [[0.05 0.05 0.05]; [0.75 0.75 0.75]];
for ss = 1:size(irf_decomp,3) % shock
    hh = figure;
    %set(gcf,'PaperPositionMode','auto')
    %set(hh, 'Position', [10, 10, 500, 300])
    for iii = 1:2
        subplot(2,2,iii)
        if (iii==1)
            z1 = squeeze(irf_decomp_ful(2:3,:,ss));
        else
            z1 = squeeze(irf_decomp_pat(2:3,:,ss));
        end
        ix = z1 > 0;
        ymax = max(sum(z1.*ix));
        ix = z1 < 0;
        ymin = min(sum(z1.*ix));
        y_grid = zeros(2,nirf);
        %figure
%        ax=axes('Position',[0.1300 0.1300 0.7750 0.8150]);
%        axis(ax,[1 nirf ymin ymax]);
        %line1=plot(ax,1:nirf, squeeze(irf_decomp_ful(1,:,ss)), 'Color',[0.1,0.1,0.1],'LineWidth',2.5);
        hold on;
        for i=1:nirf
            i_1 = i-1;
            yp = 0;
            ym = 0;
            for k = 1:2
                zz = z1(k,i);
                if zz > 0
                    ps= fill([i i i+1 i+1],[yp yp+zz yp+zz yp],color(k,:),'facealpha',.6);
                    %ps = patch([i i i+1 i+1],[yp yp+zz yp+zz yp],colorstr,'FaceAlpha',0.7,'EdgeColor','none');
                    uistack(ps,'bottom')
                    yp = yp+zz;
                else
                    ps2 = fill([i i i+1 i+1],[ym ym+zz ym+zz ym],color(k,:),'facealpha',.6);
                    uistack(ps2,'bottom')
                    ym = ym+zz;
                end
                hold on;
            end
            y_grid(:,i) = [yp ym];
        end
        y_gridmm = [max(y_grid(1,:)) min(y_grid(2,:))];
        if (iii==1)
            %line1=plot(ax,1:nirf, squeeze(irf_decomp_ful(1,:,ss)), 'blue','LineWidth',2.5);
            line1=plot(1:nirf, squeeze(irf_decomp_ful(1,:,ss)), 'blue','LineWidth',2.5);
            title('Full-time employment');
        else
            %line1=plot(ax,1:nirf, squeeze(irf_decomp_pat(1,:,ss)), 'blue','LineWidth',2.5);
            line1=plot(1:nirf, squeeze(irf_decomp_pat(1,:,ss)), 'blue','LineWidth',2.5);
            title('Part-time employment');
        end
        axis tight
        %title(deblank(char(shock_name_temp(ss,:))));

        axes('Position',[.37 .47 .2 0.47]);
        axis([0 1 0 1]);
        axis off;
        hold on;
        y1 = 0.0;
        y2 = 0.08;
        width = 0.11;
        width2 = width + 0.04;
        space = 0.9;
        height = 1/2;
        %labels = char(shock_name,'Init. values');  
        for i=1:2
            ps=fill([0+space*(i-1)  0+space*(i-1) width+space*(i-1) width+space*(i-1)],[y1 y1+y2 y1+y2 y1],color(i,:),'facealpha',.6);
            hold on
            text(width2+space*(i-1),(y1+y2)/2,labels(i),'Interpreter','none');
            %y1 = y1 + height;
        end
        h = findobj(gca,'Type','patch');
        set(h,'EdgeColor','none');
        set(gca, 'Layer', 'top')
    end
    %set(hh,'Units','Inches');
    %pos = get(hh,'Position');
    %set(hh,'PaperPositionMode','Auto','PaperUnits','Inches','PaperSize',[pos(3), pos(4)])
    %pos = get(gcf,'paperposition');
    %set(gcf,'paperposition',[pos(1),pos(2)*1.5, pos(3), pos(4)]);
    print(hh,['Decomposed_irfs_',sprintf('%s',char(cellexoval(ss))) '.eps'],'-depsc2');
    print(hh,['Decomposed_irfs_',sprintf('%s',char(cellexoval(ss))) '.pdf'],'-dpdf');
    %print(['Decomposed_irfs_',sprintf('%s',char(cellexoval(ss))) '.eps'],'-depsc2');
end
cd(oldFolder)
% 
% DirectoryName = [ M_.fname '/decomposed_irfs_slides' ];
% if ~isdir(DirectoryName)
%     mkdir('.',DirectoryName);
% end
% temp = strcat('./',DirectoryName);
% oldFolder =  cd(temp);
% labels = {'from U', 'from another E'};
% color = [[0.05 0.05 0.05]; [0.75 0.75 0.75]];
% for ss = 1:size(irf_decomp,3) % shock
%     hh = figure;
%     %set(gcf,'PaperPositionMode','auto')
%     %set(hh, 'Position', [10, 10, 500, 300])
%     for iii = 1:2
%         subplot(2,2,iii)
%         if (iii==1)
%             z1 = squeeze(irf_decomp_ful(2:3,:,ss));
%         else
%             z1 = squeeze(irf_decomp_pat(2:3,:,ss));
%         end
%         ix = z1 > 0;
%         ymax = max(sum(z1.*ix));
%         ix = z1 < 0;
%         ymin = min(sum(z1.*ix));
%         y_grid = zeros(2,nirf);
%         %figure
% %        ax=axes('Position',[0.1300 0.1300 0.7750 0.8150]);
% %        axis(ax,[1 nirf ymin ymax]);
%         %line1=plot(ax,1:nirf, squeeze(irf_decomp_ful(1,:,ss)), 'Color',[0.1,0.1,0.1],'LineWidth',2.5);
%         hold on;
%         for i=1:nirf
%             i_1 = i-1;
%             yp = 0;
%             ym = 0;
%             for k = 1:2
%                 zz = z1(k,i);
%                 if zz > 0
%                     ps= fill([i i i+1 i+1],[yp yp+zz yp+zz yp],color(k,:),'facealpha',.6);
%                     %ps = patch([i i i+1 i+1],[yp yp+zz yp+zz yp],colorstr,'FaceAlpha',0.7,'EdgeColor','none');
%                     uistack(ps,'bottom')
%                     yp = yp+zz;
%                 else
%                     ps2 = fill([i i i+1 i+1],[ym ym+zz ym+zz ym],color(k,:),'facealpha',.6);
%                     uistack(ps2,'bottom')
%                     ym = ym+zz;
%                 end
%                 hold on;
%             end
%             y_grid(:,i) = [yp ym];
%         end
%         y_gridmm = [max(y_grid(1,:)) min(y_grid(2,:))];
%         if (iii==1)
%             %line1=plot(ax,1:nirf, squeeze(irf_decomp_ful(1,:,ss)), 'blue','LineWidth',2.5);
%             line1=plot(1:nirf, squeeze(irf_decomp_ful(1,:,ss)), 'blue','LineWidth',2.5);
%             title('Full-time employment');
%         else
%             %line1=plot(ax,1:nirf, squeeze(irf_decomp_pat(1,:,ss)), 'blue','LineWidth',2.5);
%             line1=plot(1:nirf, squeeze(irf_decomp_pat(1,:,ss)), 'blue','LineWidth',2.5);
%             title('Part-time employment');
%         end
%         axis tight
%         %title(deblank(char(shock_name_temp(ss,:))));
% 
%         axes('Position',[.37 .47 .2 0.47]);
%         axis([0 1 0 1]);
%         axis off;
%         hold on;
%         y1 = 0.0;
%         y2 = 0.08;
%         width = 0.11;
%         width2 = width + 0.04;
%         space = 0.9;
%         height = 1/2;
%         %labels = char(shock_name,'Init. values');  
%         for i=1:2
%             ps=fill([0+space*(i-1)  0+space*(i-1) width+space*(i-1) width+space*(i-1)],[y1 y1+y2 y1+y2 y1],color(i,:),'facealpha',.6);
%             hold on
%             text(width2+space*(i-1),(y1+y2)/2,labels(i),'Interpreter','none');
%             %y1 = y1 + height;
%         end
%         h = findobj(gca,'Type','patch');
%         set(h,'EdgeColor','none');
%         set(gca, 'Layer', 'top')
%     end
%     %set(hh,'Units','Inches');
%     %pos = get(hh,'Position');
%     %set(hh,'PaperPositionMode','Auto','PaperUnits','Inches','PaperSize',[pos(3), pos(4)])
%     %pos = get(gcf,'paperposition');
%     %set(gcf,'paperposition',[pos(1),pos(2)*1.5, pos(3), pos(4)]);
%     print(hh,['Decomposed_irfs_',sprintf('%s',char(cellexoval(ss))) '.eps'],'-depsc2');
%     print(hh,['Decomposed_irfs_',sprintf('%s',char(cellexoval(ss))) '.pdf'],'-dpdf');
%     %print(['Decomposed_irfs_',sprintf('%s',char(cellexoval(ss))) '.eps'],'-depsc2');
% end
% cd(oldFolder)