% This file is used to nake tables and figures to report estimation results 
% Kazuhiro Teramoto

clc
clear all
close all

set(0,'defaultAxesFontSize',12);
set(0,'defaultAxesFontName','Times');
set(0,'defaultTextFontSize',12);
set(0,'defaultTextFontName','Times');

startDate = datenum('01-01-1979');
endDate = datenum('10-01-2018');
xData = linspace(startDate,endDate,4*(2019-1979));
% recession
start=[datenum('01-01-1980') datenum('07-01-1981') datenum('07-01-1990') datenum('03-01-2001') datenum('12-01-2007')];
finish=[datenum('07-01-1980') datenum('11-01-1982') datenum('03-01-1991') datenum('11-01-2001') datenum('06-01-2009')];

result = dir('*_results.mat');
load(result.name);
filename  = M_.dname;
datafile  = options_.datafile;
paranames = M_.param_names;
endonames = M_.endo_names;
obs_names = options_.varobs;
exo_names = M_.exo_names;
paravalue = M_.params;
sig_value = diag(M_.Sigma_e);
paravalue_str = num2str(paravalue,16);
[nendo nchar_endo]= size(M_.endo_names);
[n_exo nchar_exo]= size(exo_names);
[nobs nchar_obs]= size(obs_names);
if (size(M_.param_names,1) ~=  size(paravalue_str,1))
    error('parameter size is strange')
end
% set parameter values
for i = 1:size(M_.param_names,1)
    eval(cell2mat( (strcat('index_',deblank(M_.param_names(i,:)),'=',num2str(i),';'))));
    eval(cell2mat( strcat(deblank(M_.param_names(i,:)),'=',paravalue_str(i,:),';')));
end
% find estimated parameters among parameters above
index_estparas = estim_params_.param_vals(:,1);
est_para_name_cell = cellstr(M_.param_names(index_estparas,:));
est_para_name_cell_tex = cellstr(M_.param_names_tex(index_estparas,:));

% set indexes for endogenous varibles
set_variables_index;


nvx  = estim_params_.nvx;   % shocks_std
nvn  = estim_params_.nvn;   % measurement_errors_std
ncx  = estim_params_.ncx;   % shocks_corr
ncn  = estim_params_.ncn;   % measurement_errors_corr
np   = estim_params_.np ;   % parameters
npar = nvx+nvn+ncx+ncn+np;
MaxNumberOfPlotPerFigure = 9;
number_of_rows = 3;
number_of_columns = 3;
nn = sqrt(MaxNumberOfPlotPerFigure);

% making the estimation table (Table 3)
making_table;


% bayesian_irfs ( Figures 3 and 5) 
birf2 = 1;
nirf = options_.irf;
varlist = options_.varlist;
if isempty(varlist)
    varlist = char(options_.varobs);
end
cellvar = cellstr(varlist);
nvar = size(cellvar,1);
MAX_nirfs_dsge = ceil(options_.MaxNumberOfBytes/(options_.irf*nvar*M_.exo_nbr)/8);
MAX_nruns = ceil(options_.MaxNumberOfBytes/(npar+2)/8);

for i = 1:nvar
    eval(cell2mat(strcat('varlist_',options_.varlist(i,:),'=',num2str(i),';')));
end

MeanIRFdsgevar = zeros(options_.irf,nvar,M_.exo_nbr);
MedianIRFdsgevar = zeros(options_.irf,nvar,M_.exo_nbr);
DistribIRFdsgevar = zeros(options_.irf,9,nvar,M_.exo_nbr);
HPDIRFdsgevar = zeros(options_.irf,2,nvar,M_.exo_nbr);
tit(1:nvar,:) = varlist;
for i = 1:n_exo
    for j = 1:nvar
        name = cell2mat([deblank(tit(j,:)) '_' deblank(char(cellexoval(i)))]);
        MeanIRFdsgevar(:,j,i) = eval(strcat('oo_.PosteriorIRF.dsge.Mean.',name));
        MedianIRFdsgevar(:,j,i) = eval(strcat('oo_.PosteriorIRF.dsge.Median.',name));
        DistribIRFdsgevar(:,:,j,i) = eval(strcat('oo_.PosteriorIRF.dsge.deciles.',name));
        HPDIRFdsgevar(:,1,j,i) = eval(strcat('oo_.PosteriorIRF.dsge.HPDsup.',name));
        HPDIRFdsgevar(:,2,j,i) = eval(strcat('oo_.PosteriorIRF.dsge.HPDinf.',name));
    end
end

bayesian_irf_comparison;
bayesian_irf_counterfactual;



% 
set(0,'defaultAxesFontSize',13);
set(0,'defaultAxesFontName','Times');
set(0,'defaultTextFontSize',13);
set(0,'defaultTextFontName','Times');

% distinguish endogenous variables into four classifications
% p39  http://www.dynare.org/manual/index_26.html
n_pure_backward = M_.npred;   %% t and t(-1)
n_pure_forward  = M_.nfwrd;   %% t and t(+1)
n_mixed         = M_.nboth;   %% t(-1), t, t(+1)
n_static        = M_.nstatic;
n_endo = n_pure_backward + n_pure_forward + n_mixed + n_static;
n_expect        = M_.nboth + M_.nfwrd;
if (nendo ~= n_endo)
    error('error in declaration of endonegous variables')
end
DR_order = oo_.dr.inv_order_var(1:M_.endo_nbr);   %% map declared order to DR order
% The DR-order is the following:
% static variables, purely backward variables, mixed variables, purely forward variables.
static_var = M_.endo_names(oo_.dr.order_var(1:n_static),1:nchar_endo);
pure_backward_var = M_.endo_names(oo_.dr.order_var(n_static+1:n_pure_backward+n_static),1:nchar_endo);
mixed_var  = M_.endo_names(oo_.dr.order_var(n_pure_backward+n_static+1:n_mixed+n_pure_backward+n_static),1:nchar_endo);
forward_var  = M_.endo_names(oo_.dr.order_var(n_mixed+n_pure_backward+n_static+1:n_endo),1:nchar_endo);
% find index with forward-looking endogenous variables 
index_expect_var = oo_.dr.order_var(n_endo-n_expect+1:n_endo); 

max_lead = M_.maximum_endo_lead;
max_lag = M_.maximum_endo_lag;
endo_nbr = M_.endo_nbr;
lead_lag_incidence = M_.lead_lag_incidence;
klen = max_lag + max_lead + 1;
fwrd_var = find(lead_lag_incidence(max_lag+2:end,:))';

if max_lag > 0
    pred_var = find(lead_lag_incidence(1,:))';
    both_var = intersect(pred_var,fwrd_var);
    pred_var = setdiff(pred_var,both_var);
    fwrd_var = setdiff(fwrd_var,both_var);
    stat_var = setdiff([1:endo_nbr]',union(union(pred_var,both_var),fwrd_var));  % static variables
else
    pred_var = [];
    both_var = [];
    stat_var = setdiff([1:endo_nbr]',fwrd_var);
end
if options_.block == 1
    order_var = M_.block_structure.variable_reordered;
else
    order_var = [ stat_var(:); pred_var(:); both_var(:); fwrd_var(:)];
end
inv_order_var(order_var) = (1:endo_nbr);
if max_lag > 0
    kmask = [];
    if max_lead > 0
        kmask = lead_lag_incidence(max_lag+2,order_var) ;
    end
    kmask = [kmask; lead_lag_incidence(1,order_var)] ;
else
    if max_lead==0 %%in this case lead_lag_incidence has no entry max_lag+2
        error('Dynare currently does not allow to solve purely static models in a stochastic context.')
    end
    kmask = lead_lag_incidence(max_lag+2,order_var) ;
end
kmask = kmask';
kmask = kmask(:);
i_kmask = find(kmask);
nd = nnz(kmask);           % size of the state vector
kmask(i_kmask) = (1:nd);

% auxiliary equations
% composition of state vector
% col 1: variable;           col 2: lead/lag in z(t+1);
% col 3: A cols for t+1 (D); col 4: A cols for t (E)
kstate = [ repmat([1:endo_nbr]',klen-1,1) kron([klen:-1:2]',ones(endo_nbr,1)) ...
    zeros((klen-1)*endo_nbr,2)];
kiy = flipud(lead_lag_incidence(:,order_var))';
kiy = kiy(:);
if max_lead > 0
    kstate(1:endo_nbr,3) = kiy(1:endo_nbr)-nnz(lead_lag_incidence(max_lag+1,:));
    kstate(kstate(:,3) < 0,3) = 0;
    kstate(endo_nbr+1:end,4) = kiy(2*endo_nbr+1:end);
else
    kstate(:,4) = kiy(endo_nbr+1:end);
end
kstate = kstate(i_kmask,:);

%order_var = order_var;
inv_order_var = inv_order_var';
%dr.kstate = kstate;
transition_auxiliary_variables = [];

% Make Figure 4
smoother;


% Conterfactual simulation (Figure 6)
counterfactual_analysis;


% net_flow decomposition during GR
initial_gr2 = 4*(2008-1979)+1; % ('01-01-2006')
end_gr2 =  4*(2010-1979);
selected_variables = [n_ful  n_pat flow_EU_ful flow_EE_ful flow_EU_pat flow_EE_pat];
y_labor = yp_cf(selected_variables,initial_gr2-1:end_gr2);
length_GR = size(y_labor,2)-1;

flow_EU_ful_ss=sstar_ful*uss_ful/nss_ful-(1-rhoss_ful)*(1-lam_fp); 
flow_EE_ful_ss=varphi_ss*rhoss_pat*nss_pat/nss_ful- lam_fp*(1-rhoss_ful); 
flow_EU_pat_ss=sstar_pat*uss_pat/nss_pat-(1-rhoss_pat); 
flow_EE_pat_ss=-varphi_ss*rhoss_pat+lam_fp*(1-rhoss_ful)*nss_ful/nss_pat;

emp_stock_GR = y_labor(1:2,:);
flow_EU_ful_sum_GR =  flow_EU_ful_ss*y_labor(3,2:end)*triu(ones(length_GR,length_GR));
flow_EE_ful_sum_GR =  flow_EE_ful_ss*y_labor(4,2:end)*triu(ones(length_GR,length_GR));
flow_EU_pat_sum_GR =  flow_EU_pat_ss*y_labor(5,2:end)*triu(ones(length_GR,length_GR));
flow_EE_pat_sum_GR =  flow_EE_pat_ss*y_labor(6,2:end)*triu(ones(length_GR,length_GR));

rate_of_change = emp_stock_GR(:,end)-emp_stock_GR(:,1);
fid = fopen('IRF_decomposition_table_GR.tex','w');
fprintf(fid, '\n');
fprintf(fid,'\\begin{table}[h]\n');
fprintf(fid,'\\caption{ Net flow decomposition of employment stocks during Great Recession: Model} \n');
fprintf(fid,'\\centering \n \\small \n');
fprintf(fid,'\\resizebox{\\textwidth}{!}{ \n');
fprintf(fid,'{\\tabcolsep = 1.0mm \n');
fprintf(fid,'\\begin{tabular}{clccc}\n');
fprintf(fid,'\\toprule \n');
fprintf(fid,' &&  Full-time employment 	&&	Part-time employment \\\\ \\midrule \n');
fprintf(fid,' The rate of change in employment stock && %8.2f &&  %8.2f  \\\\   \\midrule \n',  rate_of_change(1), rate_of_change(2));
fprintf(fid,' Net flow from $EF$  && -- && %8.2f  \\\\ \n',  flow_EE_pat_sum_GR(end));
fprintf(fid,' Net flow from $EP$  && %8.2f && --  \\\\ \n',  flow_EE_ful_sum_GR(end));
fprintf(fid,' Net flow from $U$  && %8.2f && %8.2f \\\\ \n',  flow_EU_ful_sum_GR(end), flow_EU_pat_sum_GR(end));
fprintf(fid, '\\bottomrule  \n');
fprintf(fid, '\\end{tabular} \n');
fprintf(fid, '}} \n');
fprintf(fid, '\\raggedright \n \\vspace{2mm}\n');
fprintf(fid, '\n');
fprintf(fid, '  \\begin{minilinespace}\n  \\begin{footnotesize}\n'); 
fprintf(fid, '  \\textit{Note}:   \n'); 
fprintf(fid, '  \\end{footnotesize} \n  \\end{minilinespace} \\label{table_NFD_GR} \n\\end{table} \n');
%fprintf(fid,'\\cline{2-6}\n');
fopen(fid);


% irfs decomposition (Table 5)
IRF_decomposition;

% Total hours (Figure 7)
IRF_hours;

% Total hours 
Decomposition_total_hours;

% plot Autocovariance functions (Figure C1)
Stochastic_simulation;


% draws impulse response of other variables (Figures C2 and C3)
irf_other_variables;


